<?php
if ( ! function_exists( 'catchbox_register_styles' ) ) :
	/**
	 * Register theme styles
	 *
	 * Registers stylesheets used by the theme.
	 * Also offers integration with Google Web Fonts Directory
	 * @uses wp_register_style() To register styles
	 *
	 * @since Catch Box Pro 1.0.
	 */
	function catchbox_register_styles() {
		$options  = catchbox_get_options();

		$fontbody = $options['body_font'];
		$fonttitle = $options['title_font'];
		$fontheading = $options['headings_font'];
		$fontcontent = $options['content_font'];

		$web_fonts = array(
			'allan'					=> 'Allan',
			'allerta'				=> 'Allerta',
			'amaranth'				=> 'Amaranth',
			'bitter'				=> 'Bitter',
			'cabin'					=> 'Cabin',
			'cantarell'				=> 'Cantarell',
			'crimson-text'			=> 'Crimson+Text',
			'dancing-script'		=> 'Dancing+Script',
			'droid-sans'			=> 'Droid+Sans',
			'droid-serif'			=> 'Droid+Serif',
			'istok-web'				=> 'Istok+Web',
			'lato'					=> 'Lato',
			'lobster'				=> 'Lobster',
			'lora'					=> 'Lora',
			'nobile'				=> 'Nobile',
			'open-sans'				=> 'Open+Sans',
			'oswald'				=> 'Oswald',
			'patua-one'				=> 'Patua+One',
			'playfair-display'		=> 'Playfair+Display',
			'pt-sans'				=> 'PT+Sans',
			'pt-serif'				=> 'PT+Serif',
			'quattrocento-sans' 	=> 'Quattrocento+Sans',
			'ubuntu'				=> 'Ubuntu',
			'yanone-kaffeesatz' 	=> 'Yanone+Kaffeesatz'
		);

		if ( empty( $options['reset_typography'] )  && ( array_key_exists( $fontbody, $web_fonts ) || array_key_exists( $fonttitle, $web_fonts ) || array_key_exists( $fontheading, $web_fonts ) || array_key_exists( $fontcontent, $web_fonts ) ) ) {

			$web_fonts_stylesheet = 'http' . ( is_ssl() ? 's' : '' ) . '://fonts.googleapis.com/css?family=';

			if ( array_key_exists( $fontbody, $web_fonts ) ) {
				$web_fonts_stylesheet .= $web_fonts[$fontbody] . ':300,300italic,regular,italic,600,600italic';
			}

			if ( array_key_exists( $fonttitle, $web_fonts ) ) {
				if ( array_key_exists( $fontbody, $web_fonts ) ) {
					$web_fonts_stylesheet .='%7c';
				}
				$web_fonts_stylesheet .= $web_fonts[$fonttitle] . ':300,300italic,regular,italic,600,600italic';
			}

			if ( array_key_exists( $fontheading, $web_fonts ) ) {
				if ( array_key_exists( $fontbody, $web_fonts ) || array_key_exists( $fonttitle, $web_fonts ) ) {
					$web_fonts_stylesheet .='%7c';
				}
				$web_fonts_stylesheet .= $web_fonts[$fontheading] . ':300,300italic,regular,italic,600,600italic';
			}

			if ( array_key_exists( $fontcontent, $web_fonts ) ) {
				if ( array_key_exists( $fontbody, $web_fonts ) || array_key_exists( $fonttitle, $web_fonts ) || array_key_exists( $fontheading, $web_fonts ) ) {
					$web_fonts_stylesheet .='%7c';
				}
				$web_fonts_stylesheet .= $web_fonts[$fontcontent] . ':300,300italic,regular,italic,600,600italic';
			}

			$web_fonts_stylesheet .= '&subset=latin';

		}
		else {

			$web_fonts_stylesheet = false;

		}

		if ( false !== $web_fonts_stylesheet ) {
			wp_register_style( 'catchbox-web-font', $web_fonts_stylesheet, false, null );
			$catchbox_deps = array( 'catchbox-web-font' );
		}
		else {
			$catchbox_deps = false;
		}

		wp_register_style( 'catch-box-pro-style', get_stylesheet_uri(), $catchbox_deps, null );
	}
endif;
add_action( 'init', 'catchbox_register_styles' );


/**
 * Register jquery scripts
 *
 * @register jquery cycle and custom-script
 * hooks action wp_enqueue_scripts
 */
function catchbox_scripts_method() {
	global $wp_query;

	// Get value from Theme Options panel
	$options = catchbox_get_options();
	$enableslider = $options['enable_slider'];

	// Front page displays in Reading Settings
	$page_for_posts = get_option('page_for_posts');

	// Get Page ID outside Loop
	$page_id = $wp_query->get_queried_object_id();

	// Enqueue CatchBox Sytlesheet
	wp_enqueue_style( 'catch-box-pro-style' );

	//For genericons
	wp_enqueue_style( 'genericons', get_template_directory_uri() . '/genericons/genericons.css', false, '3.4.1' );

	// Register JQuery cycle all and JQuery set up as dependent on Jquery-cycle
	wp_register_script( 'jquery-cycle', get_template_directory_uri() . '/js/jquery.cycle.all.min.js', array( 'jquery' ), '20140315', true );

	// Slider JS load loop
	if ( ( 'enable-slider-allpage' == $enableslider ) || ( ( is_front_page() || ( is_home() && $page_id != $page_for_posts ) ) && 'enable-slider-homepage' == $enableslider ) ) {
		wp_enqueue_script( 'catchbox-slider', get_template_directory_uri() . '/js/catchbox-slider.js', array( 'jquery-cycle' ), '20140315', true );
	}

	wp_enqueue_script( 'catchbox-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151112', true );

	/**
	 * Loads up Responsive stylesheet and Menu JS
	 */
	if ( empty ($options['disable_responsive'] ) ) {
		wp_enqueue_style( 'catchbox-responsive', get_template_directory_uri() . '/css/responsive.css' );

		wp_enqueue_script( 'catchbox-menu', get_template_directory_uri() . '/js/menu.min.js', array('jquery'), '20170124', false );

		wp_localize_script( 'catchbox-menu', 'screenReaderText', array(
			'expand'   => esc_html__( 'expand child menu', 'catch-box-pro' ),
			'collapse' => esc_html__( 'collapse child menu', 'catch-box-pro' ),
		) );

		wp_enqueue_script( 'jquery-fitvids', get_template_directory_uri() . '/js/catchbox-fitvids.min.js', array( 'jquery' ), '20140315', true );
	}

	/**
	 * Adds JavaScript to pages with the comment form to support
	 * sites with threaded comments (when in use).
	 */
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	// Adds JavaScript for handling the navigation menu hide-and-show behavior.
	wp_enqueue_script( 'catchbox-navigation', get_template_directory_uri() . '/js/navigation.js', array( 'jquery' ), '20152512', true );

	/**
	 * Loads up Scroll Up script
	 */
	if ( empty( $options['disable_scrollup'] ) ) {
		wp_enqueue_script( 'catchbox-scrollup', get_template_directory_uri() . '/js/catchbox-scrollup.min.js', array( 'jquery' ), '20072014', true  );
	}

	// Load the html5 shiv.
	wp_enqueue_script( 'catchbox-html5', get_template_directory_uri() . '/js/html5.min.js', array(), '3.7.3' );
	wp_script_add_data( 'catchbox-html5', 'conditional', 'lt IE 9' );
} // catchbox_scripts_method
add_action( 'wp_enqueue_scripts', 'catchbox_scripts_method' );


/**
 * Register script for admin section
 *
 * No scripts should be enqueued within this function.
 * jquery cookie used for remembering admin tabs, and potential future features... so let's register it early
 * @uses wp_register_script
 * @action admin_enqueue_scripts
 */
function catchbox_register_js() {
	//jQuery Cookie
	wp_register_script( 'jquery-cookie', get_template_directory_uri() . '/js/jquery.cookie.min.js', array( 'jquery' ), '1.0', true );
}
add_action( 'admin_enqueue_scripts', 'catchbox_register_js' );


if ( ! function_exists( 'catchbox_responsive' ) ) :
/**
 * Responsive Layout
 *
 * @get the data value of responsive layout from theme options
 * @display responsive meta tag
 * @action wp_head
 */
function catchbox_responsive() {
	//delete_transient('catchbox_responsive');

	if ( !$catchbox_responsive = get_transient( 'catchbox_responsive' ) ) {
		$options  = catchbox_get_options();

		if ( $options['disable_responsive'] == '0' ) {
			$catchbox_responsive = '<meta name="viewport" content="width=device-width, initial-scale=1">';
		}
		else {
			$catchbox_responsive = '<!-- Disable Responsive -->';
		}
		set_transient( 'catchbox_responsive', $catchbox_responsive, 86940 );
	}
	echo $catchbox_responsive;
}
endif; // catchbox_responsive
add_filter( 'wp_head', 'catchbox_responsive', 1 );


/**
 * Add Assissibkity ready skip link
 *
 * @since Catch Box 4.5
 */
if ( ! function_exists( 'catchbox_skiptocontain' ) ) :
	/**
	 * Display Skip to Contain Link
	 */
	function catchbox_skiptocontain() {
		echo '<a href="#main" class="skip-link screen-reader-text">' . esc_html__( 'Skip to content', 'catch-box-pro' ) . '</a>';
	}
endif; // catchbox_breadcrumb_display
add_action( 'catchbox_before_header', 'catchbox_skiptocontain', 10 );


/**
 * Enqueue the styles for the current color scheme.
 *
 * @since Catch Box 1.0
 */
function catchbox_enqueue_color_scheme() {
	$options      = catchbox_get_options();

	$color_scheme = $options['color_scheme'];

	$enqueue_schemes = array( 'dark', 'blue', 'green', 'red', 'brown', 'orange' );

	if ( in_array( $color_scheme, $enqueue_schemes ) ) {
		wp_enqueue_style( $color_scheme, get_template_directory_uri() . '/colors/' . $color_scheme . '.css', array( 'catch-box-pro-style' ), null );
	}

	do_action( 'catchbox_enqueue_color_scheme', $color_scheme );
}
add_action( 'wp_enqueue_scripts', 'catchbox_enqueue_color_scheme' );


if ( ! function_exists( 'catchbox_inline_css' ) ) :
	/**
	 * Hooks the Custom Inline CSS to head section
	 *
	 * @since Catch Box Pro 1.0
	 */
	function catchbox_inline_css() {
		delete_transient( 'catchbox_inline_css' );

		if ( ( !$catchbox_inline_css = get_transient( 'catchbox_inline_css' ) ) ) {
			echo '<!-- refreshing cache -->' . "\n";

			$options  = catchbox_get_options();
			$defaults = catchbox_defaults();

			$fonts = catchbox_available_fonts();

	        $catchbox_inline_css = '';

			// Header Margin Options
			$catchbox_header_css = '';
				//Header Top Margin
				if ( $defaults['header_top_size'] != $options['header_top_size'] || $defaults['header_top_size_unit'] != $options['header_top_size_unit'] ) {
					$catchbox_header_css	.=  "padding-top: ".$options['header_top_size'] . $options['header_top_size_unit'] .";". "\n";
				}
				//Header Right Margin
				if ( $defaults['header_right_size'] != $options['header_right_size'] || $defaults['header_right_size_unit'] != $options['header_right_size_unit'] ) {
					$catchbox_header_css	.=  "margin-right: ".$options['header_right_size'] . $options['header_right_size_unit'] .";". "\n";
				}
				//Header Bottom Margin
				if ( $defaults['header_bottom_size'] != $options['header_bottom_size'] || $defaults['header_bottom_size_unit'] != $options['header_bottom_size_unit'] ) {
					$catchbox_header_css	.=  "padding-bottom: ".$options['header_bottom_size'] . $options['header_bottom_size_unit'] .";". "\n";
				}
				//Header Left Margin
				if ( $defaults['header_left_size'] != $options['header_left_size'] || $defaults['header_left_size_unit'] != $options['header_left_size_unit'] ) {
					$catchbox_header_css	.=  "margin-left: ".$options['header_left_size'] . $options['header_left_size_unit'] .";". "\n";
				}

			if ( '' != $catchbox_header_css ) {
				$catchbox_inline_css =  "#header-content {" . "\n". $catchbox_header_css . "}". "\n";
			}

			//Color Options
				// Header Background
				if ( $defaults[ 'header_background' ] != $options['header_background'] ) {
					$catchbox_inline_css	.=  "#branding { background-color: ".  $options['header_background'] ."; }". "\n";
				}
				// Slider Background
				if ( $defaults[ 'slider_background' ] != $options['slider_background'] ) {
					$catchbox_inline_css	.=  "#slider { background-color: ".  $options['slider_background'] ."; }". "\n";
				}
				// Content Background
				if ( $defaults[ 'content_background' ] != $options['content_background'] ) {
					$catchbox_inline_css	.=  "#main { background-color: ".  $options['content_background'] ."; }". "\n";
				}
				// Article Background
				if ( $defaults[ 'article_background' ] != $options['article_background'] ) {
					$catchbox_inline_css	.=  ".hentry, .no-results, #author-info, #disqus_thread, #content .error404 { background-color: ".  $options['article_background'] ."; }". "\n";
				}
				// Footer Background
				if ( $defaults[ 'footer_background' ] != $options['footer_background'] ) {
					$catchbox_inline_css	.=  "#site-generator { background-color: ".  $options['footer_background'] ."; }". "\n";
				}
				// Footer Sidebar Bacground
				if ( $defaults[ 'footer_sidebar_background' ] != $options['footer_sidebar_background'] ) {
					$catchbox_inline_css	.=  "#supplementary { background-color: ".  $options['footer_sidebar_background'] ."; }". "\n";
				}
				// Widget Background
				if ( $defaults[ 'widget_background' ] != $options['widget_background'] ) {
					$catchbox_inline_css	.=  ".widget { background-color: ".  $options['widget_background'] ."; }". "\n";
				}
				// Site Title Hover Color
				if ( $defaults[ 'title_hover_color' ] != $options['title_hover_color'] ) {
					$catchbox_inline_css	.=  "#site-title a:hover, #site-title a:focus, #site-title a:active  { color: ".  $options['title_hover_color'] ."; }". "\n";
				}
				// Title Color
				if ( $defaults[ 'text_color' ] != $options['text_color'] ) {
					$catchbox_inline_css	.=  "body, input, textarea { color: ".  $options['text_color'] ."; }". "\n";
				}
				// Heading Color
				if ( $defaults[ 'heading_color' ] != $options['heading_color'] ) {
					$catchbox_inline_css	.=  ".entry-title, .entry-title a, .post-navigation a { color: ".  $options['heading_color'] ."; }". "\n";
				}
				// Heading Hover Color
				if ( $defaults[ 'heading_hover_color' ] != $options['heading_hover_color'] ) {
					$catchbox_inline_css	.=  ".entry-title a:hover, .entry-title a:focus, .entry-title a:active, .post-navigation a:hover, .post-navigation a:focus { color: ".  $options['heading_hover_color'] ."; }". "\n";
				}
				// Meta Color
				if ( $defaults[ 'meta_color' ] != $options['meta_color'] ) {
					$catchbox_inline_css	.=  ".entry-meta { color: ".  $options['meta_color'] ."; }". "\n";
				}
				// Link Color
				if ( $defaults[ 'link_color' ] != $options['link_color'] ) {
					$catchbox_inline_css	.=  "a { color: ".  $options['link_color'] ."; }". "\n";
				}
				// Widget Heading Color
				if ( $defaults[ 'widget_heading_color' ] != $options['widget_heading_color'] ) {
					$catchbox_inline_css	.=  ".widget-area .widget-title, .widget-area .widget-title a { color: ".  $options['widget_heading_color'] ."; }". "\n";
				}
				// Widget Text Color
				if ( $defaults[ 'widget_text_color' ] != $options['widget_text_color'] ) {
					$catchbox_inline_css	.=  ".widget-area .widget, .widget-area .widget ul li { color: ".  $options['widget_text_color'] ."; }". "\n";
				}
				// Slider Text Color
				if ( $defaults[ 'slider_text' ] != $options['slider_text'] ) {
					$catchbox_inline_css	.=  "#slider-wrap .featured-text { color: ".  $options['slider_text'] ."; }". "\n";
				}
				// Menu Background Color
				if ( $defaults[ 'menu_background' ] != $options['menu_background'] ) {
					$catchbox_inline_css	.=  "#branding #access, #colophon #access-footer, .menu-access-wrap, .dropdown-toggle, .toggled-on #access ul ul a, .toggled-on #access-secondary ul ul a { background: none " .  $options['menu_background'] ."; }". "\n";
					$catchbox_inline_css	.=  "#branding ul.menu li { border: none; }". "\n";
				}
				// Menu Color
				if ( $defaults[ 'menu_color' ] != $options['menu_color'] ) {
					$catchbox_inline_css	.=  "#branding ul.menu a, #colophon #access-footer ul.menu a, .mobile-menu-anchor a.genericon-menu, .dropdown-toggle, .toggled-on #access ul ul a, .toggled-on #access-secondary ul ul a { color: " .  $options['menu_color'] ."; }". "\n";
				}
				// Menu Hover Background and Color
				if ( ( $defaults[ 'hover_background_color' ] != $options['hover_background_color'] ) || ( $defaults[ 'hover_text_color' ] != $options['hover_text_color'] ) ) {
					$catchbox_inline_css	.=  "#branding ul.menu li:hover > a, #branding ul.menu a:focus, #colophon #access-footer ul.menu a:hover, #colophon #access-footer ul.menu a:focus, .mobile-menu-anchor a.genericon-menu:hover, .mobile-menu-anchor a.genericon-menu:focus, .dropdown-toggle:hover, .dropdown-toggle:focus { background: none " .  $options['hover_background_color'] ."; color: " .  $options['hover_text_color'] ."; }". "\n";
				}
				// Menu Active Background and Color
				if ( ( $defaults[ 'active_background_color' ] != $options['active_background_color'] ) || ( $defaults[ 'active_text_color' ] != $options['active_text_color'] ) ) {
					$catchbox_inline_css	.=  "#branding .menu .current-menu-item > a, #branding .menu .current-menu-ancestor > a, #branding .menu .current_page_item > a, #branding .menu .current_page_ancestor > a, #colophon .menu .current-menu-item a, .dropdown-toggle:hover, .dropdown-toggle:focus { background: none " .  $options['active_background_color'] ."; color: " .  $options['active_text_color'] ."; }". "\n";
				}
				// SubMenu Active Background and Color
				if ( ( $defaults[ 'sub_menu_bg_color' ] != $options['sub_menu_bg_color'] ) || ( $defaults[ 'sub_menu_text_color' ] != $options['sub_menu_text_color'] ) ) {
					$catchbox_inline_css	.=  "#branding ul.menu ul a { background: none " .  $options['sub_menu_bg_color'] ."; color: " .  $options['sub_menu_text_color'] ."; }". "\n";
				}
				// Scrollup Color
				if ( ( $defaults[ 'scrollup_bg_color' ] != $options['scrollup_bg_color'] ) || ( $defaults[ 'scrollup_text_color' ] != $options['scrollup_text_color'] ) ) {
					$catchbox_inline_css	.=  "a#scrollup { background: none " .  $options['scrollup_bg_color'] ."; color: " .  $options['scrollup_text_color'] ."; }". "\n";
				}

			// Typography (Font Family) Options
			if ( $defaults[ 'body_font' ] != $options['body_font'] ) {
				$catchbox_inline_css	.=  "body, input, textarea { font-family: ". $fonts [ $options['body_font'] ] ."; }". "\n";
			}
			if ( $defaults[ 'title_font' ] != $options['title_font'] ) {
				$catchbox_inline_css	.=  "#site-title a, #site-description { font-family: ". $fonts [ $options['title_font'] ] ."; }". "\n";
			}
			if ( $defaults[ 'headings_font' ] != $options['headings_font'] ) {
				$catchbox_inline_css	.=  "h1, h2, h3, h4, h5, h6 { font-family: ". $fonts [ $options['headings_font'] ] ."; }". "\n";
			}
			if ( $defaults[ 'content_font' ] != $options['content_font'] ) {
				$catchbox_inline_css	.=  ".entry-content, .entry-summary { font-family: ". $fonts [ $options['content_font'] ] ."; }". "\n";
			}

			// Typography (Font Size) Options
			$catchbox_font_css ='';
				//Body Font Size
				if ( $defaults['body_font_size'] != $options['body_font_size'] ) {
					$catchbox_font_css	.=  "body, input, textarea { font-size: ". $options['body_font_size'] . $options['body_font_size_unit'] ."; line-height: ". $options['body_line_height'] . $options['body_line_height_unit'] .";  }". "\n";
				} elseif ( $defaults['body_line_height'] != $options['body_line_height'] ) {
					$catchbox_font_css	.=  "body, input, textarea { line-height: ". $options['body_line_height'] . $options['body_line_height_unit'] .";  }". "\n";
				}

				//Site Title Font Size
				if ( $defaults['site_title_font_size'] != $options['site_title_font_size'] ) {
					$catchbox_font_css	.=  "#site-title { font-size: ". $options['site_title_font_size'] . $options['site_title_font_size_unit'] ."; line-height: ". $options['site_title_line_height'] . $options['site_title_line_height_unit'] .";  }". "\n";
				} elseif ( $defaults['site_title_line_height'] != $options['site_title_line_height'] ) {
					$catchbox_font_css	.=  "#site-title  { line-height: ". $options['site_title_line_height'] . $options['site_title_line_height_unit'] .";  }". "\n";
				}

				//Site Description Font Size
				if ( $defaults['site_description_font_size'] != $options['site_description_font_size'] ) {
					$catchbox_font_css	.=  "#site-description { font-size: ". $options['site_description_font_size'] . $options['site_description_font_size_unit'] ."; line-height: ". $options['site_description_line_height'] . $options['site_description_line_height_unit'] .";  }". "\n";
				} elseif ( $defaults['site_description_line_height'] != $options['site_description_line_height'] ) {
					$catchbox_font_css	.=  "#site-description { line-height: ". $options['site_description_line_height'] . $options['site_description_line_height_unit'] .";  }". "\n";
				}

				//Post-Page Font Size
				if ( $defaults['title_font_size'] != $options['title_font_size'] ) {
					$catchbox_font_css	.=  ".entry-title { font-size: ".  $options['title_font_size'] . $options['title_font_size_unit'] ."; line-height: ". $options['headings_line_height'] . $options['headings_line_height_unit'] .";  }". "\n";
				}
				//H1 Font Size
				if ( $defaults['h1_font_size'] != $options['h1_font_size'] ) {
					$catchbox_font_css	.=  ".entry-content h1 { font-size: ".  $options['h1_font_size'] . $options['h1_font_size_unit'] ."; line-height: ". $options['headings_line_height'] . $options['headings_line_height_unit'] .";  }". "\n";
				}

				//H2 Font Size
				if ( $defaults['h2_font_size'] != $options['h2_font_size'] ) {
					$catchbox_font_css	.=  ".entry-content h2 { font-size: ". $options['h2_font_size'] . $options['h2_font_size_unit'] ."; line-height: ". $options['headings_line_height'] . $options['headings_line_height_unit'] .";  }". "\n";
				}

				//H3 Font Size
				if ( $defaults['h3_font_size'] != $options['h3_font_size'] ) {
					$catchbox_font_css	.=  ".entry-content h3 { font-size: ". $options['h3_font_size'] . $options['h3_font_size_unit'] ."; line-height: ". $options['headings_line_height'] . $options['headings_line_height_unit'] .";  }". "\n";
				}

				//H4 Font Size
				if ( $defaults['h4_font_size'] != $options['h4_font_size'] ) {
					$catchbox_font_css	.=  ".entry-content h4 { font-size: ". $options['h4_font_size'] . $options['h4_font_size_unit'] ."; line-height: ". $options['headings_line_height'] . $options['headings_line_height_unit'] .";  }". "\n";
				}

				//Heading Line height
				if ( $defaults['headings_line_height'] != $options['headings_line_height'] ) {
					$catchbox_font_css	.=  ".entry-content h1, .entry-content h2, .entry-content h3, .entry-content h4, .entry-content h5, .entry-content h6 { line-height: ". $options['headings_line_height'] . $options['headings_line_height_unit'] .";  }". "\n";
				}

				//Content Font Size
				if ( $defaults[ 'content_font_size' ] != $options['content_font_size'] ) {
					$catchbox_font_css	.=  ".entry-content, .entry-summary { font-size: ". $options['content_font_size'] . $options['content_font_size_unit'] ."; line-height: ". $options['content_line_height'] . $options['content_line_height_unit'] .";  }". "\n";
				}

			if ( ''!= $catchbox_font_css ) {
				$catchbox_inline_css .=  "@media screen and (min-width: 961px) {". "\n". $catchbox_font_css ."}". "\n";
			}

			//Custom CSS Option
			if ( !empty( $options['custom_css'] ) ) {
				$catchbox_inline_css	.=  $options['custom_css'] . "\n";
			}

			if ( '' != $catchbox_inline_css ){
				echo '<!-- refreshing custom css cache -->' . "\n";

				$catchbox_inline_css = '
					<!-- '.get_bloginfo('name').' inline CSS Styles -->' . "\n" . '
						<style type="text/css" media="screen">' . "\n" .
							$catchbox_inline_css . '
						</style>' . "\n";
			}

		set_transient( 'catchbox_inline_css', $catchbox_inline_css, 86940 );
		}
		echo $catchbox_inline_css;
	}
	endif; //catchbox_inline_css
add_action('wp_head', 'catchbox_inline_css');


/**
 * Sets the post excerpt length.
 *
 * To override this length in a child theme, remove the filter and add your own
 * function tied to the excerpt_length filter hook.
 */
function catchbox_excerpt_length( $length ) {
	$options  = catchbox_get_options();

	return absint( $options['excerpt_length'] );
}
add_filter( 'excerpt_length', 'catchbox_excerpt_length' );


if ( ! function_exists( 'catchbox_continue_reading_link' ) ) :
/**
 * Returns a "Continue Reading" link for excerpts
 */
function catchbox_continue_reading_link() {
	$options  = catchbox_get_options();
	if ( empty( $options['more_tag_accessible'] ) ) {
    	$more_tag_text = $options['more_tag_text'];

    	return ' <a class="more-link" href="'. esc_url( get_permalink() ) . '">' . esc_attr( $more_tag_text ) . '</a>';
    }
    else {
		$more_tag_text = $options['more_tag_text_accessible'];
		$more_tag_icon = $options['more_tag_icon_accessible'];

		return ' <a class="more-link" href="'. esc_url( get_permalink() ) . '">' . esc_attr( $more_tag_text ) . '<span class="screen-reader-text">' . get_the_title() . '</span><span class="meta-nav">' . $more_tag_icon . '</span></a>';
    }
}
endif;


/**
 * Replaces "[...]" (appended to automatically generated excerpts) with an ellipsis and catchbox_continue_reading_link().
 *
 * To override this in a child theme, remove the filter and add your own
 * function tied to the excerpt_more filter hook.
 */
function catchbox_auto_excerpt_more( $more ) {
	return catchbox_continue_reading_link();
}
add_filter( 'excerpt_more', 'catchbox_auto_excerpt_more' );


/**
 * Adds a pretty "Continue Reading" link to custom post excerpts.
 *
 * To override this link in a child theme, remove the filter and add your own
 * function tied to the get_the_excerpt filter hook.
 */
function catchbox_custom_excerpt_more( $output ) {
	if ( has_excerpt() && ! is_attachment() ) {
		$output .= catchbox_continue_reading_link();
	}
	return $output;
}
add_filter( 'get_the_excerpt', 'catchbox_custom_excerpt_more' );


if ( ! function_exists( 'catchbox_content_nav' ) ) :
/**
 * Display navigation to next/previous pages when applicable
 */
function catchbox_content_nav( $nav_id ) {
	global $wp_query;

	/**
	 * Check Jetpack Infinite Scroll
	 * if it's active then disable pagination
	 */
	if ( class_exists( 'Jetpack', false ) ) {
		$jetpack_active_modules = get_option('jetpack_active_modules');
		if ( $jetpack_active_modules && in_array( 'infinite-scroll', $jetpack_active_modules ) ) {
			return false;
		}
	}

	$nav_class = 'site-navigation paging-navigation';
	if ( is_single() )
		$nav_class = 'site-navigation post-navigation';

	if ( $wp_query->max_num_pages > 1 ) { ?>
		<nav id="<?php echo $nav_id; ?>">
        	<h3 class="screen-reader-text"><?php _e( 'Post navigation', 'catch-box-pro' ); ?></h3>
			<?php if ( function_exists('wp_pagenavi' ) )  {
                wp_pagenavi();
            }
            elseif ( function_exists('wp_page_numbers' ) ) {
                wp_page_numbers();
            }
            else { ?>
            	<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'catch-box-pro' ) ); ?></div>
                <div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'catch-box-pro' ) ); ?></div>
            <?php
            } ?>
		</nav><!-- #nav -->
	<?php
	}
}
endif; // catchbox_content_nav


if ( ! function_exists( 'catchbox_content_query_nav' ) ) :
/**
 * Display navigation to next/previous pages when applicable
 */
function catchbox_content_query_nav( $nav_id ) {
	global $wp_query;

	if ( $wp_query->max_num_pages > 1 ) { ?>
		<nav id="<?php echo $nav_id; ?>">
        	<h3 class="screen-reader-text"><?php _e( 'Post navigation', 'catch-box-pro' ); ?></h3>
			<?php if ( function_exists('wp_pagenavi' ) )  {
                wp_pagenavi();
            }
            elseif ( function_exists('wp_page_numbers' ) ) {
                wp_page_numbers();
            }
            else { ?>
            	<div class="nav-previous"><?php next_posts_link( __( '<span class="meta-nav">&larr;</span> Older posts', 'catch-box-pro' ) ); ?></div>
                <div class="nav-next"><?php previous_posts_link( __( 'Newer posts <span class="meta-nav">&rarr;</span>', 'catch-box-pro' ) ); ?></div>
            <?php
            } ?>
		</nav><!-- #nav -->
	<?php
	}
}
endif; // catchbox_content_nav


if ( ! function_exists( 'catchbox_footer_sidebar_class' ) ) :
/**
 * Count the number of footer sidebars to enable dynamic classes for the footer
 */
function catchbox_footer_sidebar_class() {
	$count = 0;

	if ( is_active_sidebar( 'sidebar-2' ) )
		$count++;

	if ( is_active_sidebar( 'sidebar-3' ) )
		$count++;

	if ( is_active_sidebar( 'sidebar-4' ) )
		$count++;

	$class = '';

	switch ( $count ) {
		case '1':
			$class = 'one';
			break;
		case '2':
			$class = 'two';
			break;
		case '3':
			$class = 'three';
			break;
	}

	if ( $class )
		echo 'class="' . $class . '"';
}
endif; // catchbox_footer_sidebar_class


if ( ! function_exists( 'catchbox_comment' ) ) :
/**
 * Template for comments and pingbacks.
 *
 * To override this walker in a child theme without modifying the comments template
 * simply create your own catchbox_comment(), and that function will be used instead.
 *
 * Used as a callback by wp_list_comments() for displaying the comments.
 *
 * @since Catch Box 1.0
 */
function catchbox_comment( $comment, $args, $depth ) {
	switch ( $comment->comment_type ) :
		case 'pingback' :
		case 'trackback' :
	?>
	<li class="post pingback">
		<p><?php _e( 'Pingback:', 'catch-box-pro' ); ?> <?php comment_author_link(); ?><?php edit_comment_link( __( 'Edit', 'catch-box-pro' ), '<span class="edit-link">', '</span>' ); ?></p>
	<?php
			break;
		default :
	?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>">
		<article id="comment-<?php comment_ID(); ?>" class="comment">
			<footer class="comment-meta">
				<div class="comment-author vcard">
					<?php
						$avatar_size = 68;
						if ( '0' != $comment->comment_parent )
							$avatar_size = 39;

						echo get_avatar( $comment, $avatar_size );

						/* translators: 1: comment author, 2: date and time */
						printf( __( '%1$s on %2$s <span class="says">said:</span>', 'catch-box-pro' ),
							sprintf( '<span class="fn">%s</span>', get_comment_author_link() ),
							sprintf( '<a href="%1$s"><time pubdate datetime="%2$s">%3$s</time></a>',
								esc_url( get_comment_link( $comment->comment_ID ) ),
								get_comment_time( 'c' ),
								/* translators: 1: date, 2: time */
								sprintf( __( '%1$s at %2$s', 'catch-box-pro' ), get_comment_date(), get_comment_time() )
							)
						);
					?>

					<?php edit_comment_link( __( 'Edit', 'catch-box-pro' ), '<span class="edit-link">', '</span>' ); ?>
				</div><!-- .comment-author .vcard -->

				<?php if ( $comment->comment_approved == '0' ) : ?>
					<em class="comment-awaiting-moderation"><?php _e( 'Your comment is awaiting moderation.', 'catch-box-pro' ); ?></em>
					<br />
				<?php endif; ?>

			</footer>

			<div class="comment-content"><?php comment_text(); ?></div>

			<div class="reply">
				<?php comment_reply_link( array_merge( $args, array( 'reply_text' => __( 'Reply <span>&darr;</span>', 'catch-box-pro' ), 'depth' => $depth, 'max_depth' => $args['max_depth'] ) ) ); ?>
			</div><!-- .reply -->
		</article><!-- #comment-## -->

	<?php
			break;
	endswitch;
}
endif; // ends check for catchbox_comment()


if ( ! function_exists( 'catchbox_posted_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 * Create your own catchbox_posted_on to override in a child theme
 *
 * @since Catch Box 1.0
 */
function catchbox_posted_on() {
	/* Check Author URL to Support Google Authorship
	*
	* By deault the author will link to author archieve page
	* But if the author have added their Website in Profile page then it will link to author website
	*/
	if ( get_the_author_meta( 'user_url' ) != '' ) {
		$catchbox_author_url = 	esc_url( get_the_author_meta( 'user_url' ) );
	}
	else {
		$catchbox_author_url = esc_url( get_author_posts_url( get_the_author_meta( "ID" ) ) );
	}
	printf( __( '<span class="sep">Posted on </span><a href="%1$s" title="%2$s" rel="bookmark"><time class="entry-date updated" datetime="%3$s" pubdate>%4$s</time></a><span class="by-author"> <span class="sep"> by </span> <span class="author vcard"><a class="url fn n" href="%5$s" title="%6$s" rel="author">%7$s</a></span></span>', 'catch-box-pro' ),
		esc_url( get_permalink() ),
		esc_attr( get_the_time() ),
		esc_attr( get_the_date( 'c' ) ),
		esc_html( get_the_date() ),
		$catchbox_author_url,
		esc_attr( sprintf( __( 'View all posts by %s', 'catch-box-pro' ), get_the_author() ) ),
		get_the_author()
	);	
}
endif;


if ( ! function_exists( 'catchbox_updated_on' ) ) :
/**
 * Prints HTML with meta information for the current post-date/time and author.
 * Create your own catchbox_posted_on to override in a child theme
 *
 * @since Catch Box Pro 4.9.3
 */
function catchbox_updated_on() {
	$options = catchbox_get_options();
    $updated = $options['show_updated'];

	$u_time = get_the_time('U'); 
	$u_modified_time = get_the_modified_time('U'); 
	if ( ( $u_modified_time >= $u_time + 86400 ) && ( $options['show_updated'] ) ) { 
		echo '<span class="post-updated">' . esc_attr__( 'Updated on ', 'catch-box-pro' ) . '<a href="' . esc_url( get_permalink() ) . '">' . esc_html( get_the_modified_date() ) . '</a></span>';
	}
}
endif;


/**
 * Adds two classes to the array of body classes.
 * The first is if the site has only had one author with published posts.
 * The second is if a singular post being displayed
 *
 * @since Catch Box 1.0
 */
function catchbox_body_classes( $classes ) {
	$layout  = catchbox_get_theme_layout();

	if ( 'no-sidebar' == $layout || is_page_template( 'page-disable-sidebar.php' ) ) {
		$classes[] = 'no-sidebar';
	}
	elseif ( 'no-sidebar-one-column' == $layout || is_page_template( 'page-onecolumn.php' ) ) {
		$classes[] = 'no-sidebar one-column';
	}
	elseif ( 'no-sidebar-full-width' == $layout || is_page_template( 'page-fullwidth.php' ) ) {
		$classes[] = 'no-sidebar full-width';
	}
	elseif ( 'left-sidebar' == $layout ) {
		$classes[] = 'left-sidebar';
	}
	elseif ( 'right-sidebar' == $layout ) {
		$classes[] = 'right-sidebar';
	}

	$options = catchbox_get_options();

	if ( ! ( ! empty ( $options['enable_sec_menu'] ) && has_nav_menu( 'secondary' ) ) ) {
		$classes[] = 'one-menu';
	}

	$position = isset( $options['header_image_position'] ) ? $options['header_image_position'] : 'above';


	if ( 'above' == $position ) {
		$classes[] = 'header-image-top';
	}

	return $classes;
}
add_filter( 'body_class', 'catchbox_body_classes' );


/**
 * Adds in post and Page ID when viewing lists of posts and pages
 * This will help the admin to add the post ID in featured slider
 *
 * @param mixed $post_columns
 * @return post columns
 */
function catchbox_post_id_column( $post_columns ) {
	$beginning = array_slice( $post_columns, 0 ,1 );
	$beginning[ 'postid' ] = __( 'ID', 'catch-box-pro'  );
	$ending = array_slice( $post_columns, 1 );
	$post_columns = array_merge( $beginning, $ending );
	return $post_columns;
}
add_filter( 'manage_posts_columns', 'catchbox_post_id_column' );
add_filter( 'manage_pages_columns', 'catchbox_post_id_column' );

function catchbox_posts_id_column( $col, $val ) {
	if ( 'postid' == $col ) echo $val;
}
add_action( 'manage_posts_custom_column', 'catchbox_posts_id_column', 10, 2 );
add_action( 'manage_pages_custom_column', 'catchbox_posts_id_column', 10, 2 );

function catchbox_posts_id_column_css() {
	echo '
	<style type="text/css">
	    #postid { width: 80px; }
	    @media screen and (max-width: 782px) {
	        .wp-list-table #postid, .wp-list-table #the-list .postid { display: none; }
	        .wp-list-table #the-list .is-expanded .postid {
	            padding-left: 30px;
	        }
	    }
    </style>';
}
add_action( 'admin_head-edit.php', 'catchbox_posts_id_column_css' );


/**
 * Function to pass the variables for php to js file.
 * This funcition passes the slider effect variables.
 */

function catchbox_pass_slider_value() {
	$options  = catchbox_get_options();
	$effect   = $options['transition_effect'];
	$delay    = $options['transition_delay'] * 1000;
	$duration = $options['transition_duration'] * 1000;

	wp_localize_script(
		'catchbox-slider',
		'js_value',
		array(
			'transition_effect'   => $effect,
			'transition_delay'    => $delay,
			'transition_duration' => $duration
		)

	);

}//catchbox_pass_slider_value


if ( ! function_exists( 'catchbox_sliders' ) ) :
/**
 * This function to display featured posts slider
 *
 * @get the data value from theme options
 * @displays on the index
 *
 * @useage Featured Image, Title and Excerpt of Post
 *
 * @uses set_transient and delete_transient
 */
function catchbox_sliders() {
	delete_transient( 'catchbox_sliders' );

	// This function passes the value of slider effect to js file
    if ( function_exists( 'catchbox_pass_slider_value' ) ) {
      	catchbox_pass_slider_value();
  	}

  	if ( !$catchbox_sliders = get_transient( 'catchbox_sliders' ) ) {
  		$options  = catchbox_get_options();

		// get slider_qty from theme options
		$postperpage   = $options['slider_qty'];
		$sliderlayout  = $options['select_slider_layout'];
		$sidebarlayout = $options['sidebar_layout'];
		$slider_array  = (array) $options['featured_slider'];
		$post_list     = array();

		foreach ( $slider_array as $slider ) {
			if ( '' != $slider && 'publish' == get_post_status( $slider ) ){
				$post_list[] = $slider;
			}
		}

		$output = '';

		if ( ! empty( $post_list ) ) {
			echo '<!-- refreshing cache -->';

			if ( 'fullwidth' == $sliderlayout ) {
				$slideclass = "post-slider slider-fullwidth";
			} else {
				$slideclass = "post-slider";
			}

			$catchbox_sliders = '
			<div id="slider" class="' . $slideclass . '">
				<section id="slider-wrap">';
				$loop = new WP_Query( array(
					'posts_per_page'      => $postperpage,
					'post__in'            => $post_list,
					'orderby'             => 'post__in',
					'ignore_sticky_posts' => 1 // ignore sticky posts
				));

				while ( $loop->have_posts()) :
					$loop->the_post();

					$title_attribute = the_title_attribute( 'echo=0' );

					if ( 0 == $loop->current_post ) {
						$classes = "slides displayblock";
					} else {
						$classes = "slides displaynone";
					}

					if ( 'fullwidth' == $sliderlayout || 'no-sidebar-full-width' == $sidebarlayout ) {
						$postimage = get_the_post_thumbnail( get_the_ID(), 'featured-slider-larger', array( 'title' => $title_attribute, 'alt' => $title_attribute ) );
					}
					else {
						$postimage = get_the_post_thumbnail( get_the_ID(), 'featured-slider', array( 'title' => $title_attribute, 'alt' => $title_attribute ) );
					}

					$catchbox_sliders .= '
					<div class="'.$classes.'">
						<a href="' . esc_url( get_permalink() ) . '" title="' . $title_attribute . '" rel="bookmark">
								' . $postimage . '
						</a>
						<div class="featured-text">'
							.the_title( '<span class="slider-title">','</span>', false ).' <span class="sep">:</span>
							<span class="slider-excerpt">'.get_the_excerpt().'</span>
						</div><!-- .featured-text -->
					</div> <!-- .slides -->';
				endwhile;
			wp_reset_postdata();

			$catchbox_sliders .= '
				</section> <!-- .slider-wrap -->

				<nav id="nav-slider">
					<div class="nav-previous"><img class="pngfix" src="'.get_template_directory_uri().'/images/previous.png" alt="next slide"></div>
					<div class="nav-next"><img class="pngfix" src="'.get_template_directory_uri().'/images/next.png" alt="next slide"></div>
				</nav>
				<div id="controllers">
				</div><!-- #controllers -->
			</div> <!-- #featured-slider -->';
			set_transient( 'catchbox_sliders', $catchbox_sliders, 86940 );
		}
		echo $catchbox_sliders;
	}
}
endif; //catchbox_sliders


if ( ! function_exists( 'catchbox_page_sliders' ) ) :
/**
 * This function to display featured page slider
 *
 * @get the data value from theme options
 * @displays on the index
 *
 * @useage Featured Image, Title and Excerpt of Post
 *
 * @uses set_transient and delete_transient
 */
function catchbox_page_sliders() {
	//delete_transient( 'catchbox_page_sliders' );

	// This function passes the value of slider effect to js file
    if ( function_exists( 'catchbox_pass_slider_value' ) ) {
      	catchbox_pass_slider_value();
  	}

	if ( !$catchbox_sliders = get_transient( 'catchbox_sliders' ) ) {
  		$options  = catchbox_get_options();

		// get slider_qty from theme options
		$postperpage   = $options['slider_qty'];
		$sliderlayout  = $options['select_slider_layout'];
		$sidebarlayout = $options['sidebar_layout'];
		$slider_array  = (array) $options['featured_slider_page'];
		$page_list     = array();

		foreach ( $slider_array as $slider ) {
			if ( '' != $slider && 'publish' == get_post_status( $slider ) ){
				$page_list[] = $slider;
			}
		}

		$catchbox_page_sliders = '';

		if ( ! empty( $page_list ) ) {
			echo '<!-- refreshing cache -->';

			if ( 'fullwidth' == $sliderlayout ) {
				$slideclass = "post-slider slider-fullwidth";
			} else {
				$slideclass = "post-slider";
			}

			$catchbox_page_sliders = '
			<div id="slider" class="' . $slideclass . '">
				<section id="slider-wrap">';
				$loop = new WP_Query( array(
					'posts_per_page'	=> $postperpage,
					'post_type'			=> 'page',
					'post__in'			=> $page_list,
					'orderby'			=> 'post__in'
				));

				while ( $loop->have_posts()) :
					$loop->the_post();

					$title_attribute = the_title_attribute( 'echo=0' );

					if ( 0 == $loop->current_post ) {
						$classes = "slides displayblock";
					} else {
						$classes = "slides displaynone";
					}

					if ( 'fullwidth' == $sliderlayout || 'no-sidebar-full-width' == $sidebarlayout ) {
						$postimage = get_the_post_thumbnail( get_the_ID(), 'featured-slider-larger', array( 'title' => $title_attribute, 'alt' => $title_attribute, 'class'	=> 'pngfix' ) );
					}
					else {
						$postimage = get_the_post_thumbnail( get_the_ID(), 'featured-slider', array( 'title' => $title_attribute, 'alt' => $title_attribute, 'class'	=> 'pngfix' ) );
					}

					$catchbox_page_sliders .= '
					<div class="'.$classes.'">
						<a href="' . esc_url( get_permalink() ) . '" title="' . $title_attribute . '" rel="bookmark">
								'.$postimage.'
						</a>
						<div class="featured-text">'
							.the_title( '<span class="slider-title">','</span>', false ).' <span class="sep">:</span>
							<span class="slider-excerpt">'.get_the_excerpt().'</span>
						</div><!-- .featured-text -->
					</div> <!-- .slides -->';
				endwhile;

			wp_reset_postdata();

			$catchbox_page_sliders .= '
				</section> <!-- .slider-wrap -->
				<nav id="nav-slider">
					<div class="nav-previous"><img class="pngfix" src="'.get_template_directory_uri().'/images/previous.png" alt="next slide"></div>
					<div class="nav-next"><img class="pngfix" src="'.get_template_directory_uri().'/images/next.png" alt="next slide"></div>
				</nav>
				<div id="controllers">
				</div><!-- #controllers -->
			</div> <!-- #featured-slider -->';

			set_transient( 'catchbox_page_sliders', $catchbox_page_sliders, 86940 );
		}
		echo $catchbox_page_sliders;
	}
}
endif; //catchbox_page_sliders


if ( ! function_exists( 'catchbox_category_sliders' ) ) :
/**
 * This function to display featured category slider
 *
 * @get the data value from theme options
 * @displays on the index
 *
 * @useage Featured Image, Title and Excerpt of Post
 *
 * @uses set_transient and delete_transient
 */
function catchbox_category_sliders() {
	global $post;

	//delete_transient( 'catchbox_category_sliders' );

	// This function passes the value of slider effect to js file
    if ( function_exists( 'catchbox_pass_slider_value' ) ) {
      	catchbox_pass_slider_value();
  	}

	// get data value from catchbox_options_slider through theme options
	$options = catchbox_get_options();
	// get slider_qty from theme options
	$postperpage = $options['slider_qty'];
	$sliderlayout = $options['select_slider_layout'];
	if ( is_array( $options['slider_category'] ) && ('0' != $options['slider_category'] ) ) {
		$cats	= (array) $options['slider_category'];
		if ( defined( "ICL_LANGUAGE_CODE" ) ) {
		    $category = array();
			    foreach( $cats as $cat){
			    	$category[] = apply_filters( 'wpml_object_id', $cat, 'category', true );
			    }
			$cats = $category;
		}
	}
	else{
		$cats = '0';
	}
	$sidebarlayout = $options['sidebar_layout'];

	if ( ( !$catchbox_category_sliders = get_transient( 'catchbox_category_sliders' ) ) ) {
		echo '<!-- refreshing cache -->';

		if ( $sliderlayout =='fullwidth' ) { $slideclass = "page-slider slider-fullwidth"; } else { $slideclass = "page-slider"; }

		$catchbox_category_sliders = '
		<div id="slider" class="'.$slideclass.'">
			<section id="slider-wrap">';
			$loop = new WP_Query( array(
				'posts_per_page'      => $postperpage,
				'category__in'        => $cats,
				'ignore_sticky_posts' => 1 // ignore sticky posts
			));

			$i=0; while ( $loop->have_posts()) : $loop->the_post(); $i++;
				$title_attribute = esc_attr( apply_filters( 'the_title', get_the_title( $post->ID ) ) );

				if ( $i == 1 ) { $classes = "slides displayblock"; } else { $classes = "slides displaynone"; }

				if ( 'fullwidth' == $sliderlayout || 'no-sidebar-full-width' == $sidebarlayout ) {
					$postimage = get_the_post_thumbnail( $post->ID, 'featured-slider-larger', array( 'title' => $title_attribute, 'alt' => $title_attribute, 'class'	=> 'pngfix' ) );
				}
				else {
					$postimage = get_the_post_thumbnail( $post->ID, 'featured-slider', array( 'title' => $title_attribute, 'alt' => $title_attribute, 'class'	=> 'pngfix' ) );
				}

				$catchbox_category_sliders .= '
				<div class="'.$classes.'">
					<a href="' . esc_url( get_permalink() ) . '" title="'.sprintf( esc_attr__( 'Permalink to %s', 'catch-box-pro' ), the_title_attribute( 'echo=0' ) ).'" rel="bookmark">
							'.$postimage.'
					</a>
					<div class="featured-text">'
						.the_title( '<span class="slider-title">','</span>', false ).' <span class="sep">:</span>
						<span class="slider-excerpt">'.get_the_excerpt().'</span>
					</div><!-- .featured-text -->
				</div> <!-- .slides -->';
			endwhile; wp_reset_postdata();
		$catchbox_category_sliders .= '
			</section> <!-- .slider-wrap -->
			<nav id="nav-slider">
				<div class="nav-previous"><img class="pngfix" src="'.get_template_directory_uri().'/images/previous.png" alt="next slide"></div>
				<div class="nav-next"><img class="pngfix" src="'.get_template_directory_uri().'/images/next.png" alt="next slide"></div>
			</nav>
			<div id="controllers">
			</div><!-- #controllers -->
		</div> <!-- #featured-slider -->';
		set_transient( 'catchbox_category_sliders', $catchbox_category_sliders, 86940 );
	}
	echo $catchbox_category_sliders;
}
endif; //catchbox_category_sliders


if ( ! function_exists( 'catchbox_imagesliders' ) ) :
/**
 * This function to display featured posts slider
 *
 * @get the data value from theme options
 * @displays on the index
 *
 * @useage Featured Image, Title and Excerpt of Post
 *
 * @uses set_transient and delete_transient
 */
function catchbox_imagesliders() {

	//delete_transient( 'catchbox_imagesliders' );

	// This function passes the value of slider effect to js file
    if ( function_exists( 'catchbox_pass_slider_value' ) ) {
      	catchbox_pass_slider_value();
  	}

	// get data value from theme options
	$options       = catchbox_get_options();
	$sliderlayout  = $options['select_slider_layout'];
	$postperpage   = $options['slider_qty'];
	$more_tag_text = esc_attr( $options['more_tag_text'] );

	if ( isset( $options['featured_image_slider_image'] ) ) {
		$slider_array = (array) $options['featured_image_slider_image'];

		if ( ( !$catchbox_imagesliders = get_transient( 'catchbox_imagesliders' ) ) && !empty( $slider_array ) ) {
			echo '<!-- refreshing cache -->';

			if ( $sliderlayout =='fullwidth' ) { $slideclass = "image-slider slider-fullwidth"; } else { $slideclass = "image-slider"; }

			$catchbox_imagesliders = '
			<div id="slider" class="'.$slideclass.'">
				<section id="slider-wrap">';

					for ( $i=0; $i<=$options['slider_qty']; $i++ ) {

						//Adding in Classes for Display blok and none
						if ( $i == 1 ) { $classes = "slides displayblock"; } else { $classes = "slides displaynone"; }

						//Check Image Not Empty to add in the slides
						if ( !empty ( $options['featured_image_slider_image'][ $i ] ) ) {

							//Checking Title
							if ( !empty ( $options['featured_image_slider_title'][ $i ] ) ) {
								$title = '<span class="slider-title">'.$options['featured_image_slider_title'][ $i ].'</span>';
								$imagetitle = $options['featured_image_slider_title'][ $i ];
							}
							else {
								$title = '';
								$imagetitle = 'Featured Image-'.$i;
							}

							//Checking Link
							if ( !empty ( $options['featured_image_slider_link'][ $i ] ) ) {
								//support for qtranslate custom link
								if ( function_exists( 'qtrans_convertURL' ) ) {
									$link = qtrans_convertURL($options['featured_image_slider_link'][ $i ]);
								}
								else {
									$link = $options['featured_image_slider_link'][ $i ];
								}
								//Checking Link Target
								if ( !empty ( $options['featured_image_slider_base'][ $i ] ) ) {
									$target = '_blank';
								} else {
									$target = '_self';
								}
								$readmore = ' <a href="' . esc_url( $link ) . '" class="more-link" target="' . $target . '">'.$more_tag_text.'</a>';
								$image = '<a href="' . esc_url( $link ) . '" title="'.$imagetitle.'" target="' . $target . '"><img title="'.$imagetitle.'" alt="'.$imagetitle.'" class="pngfix wp-post-image" src="'.$options['featured_image_slider_image'][ $i ].'" /></a>';
							}
							else {
								$link = '';
								$target = '';
								$readmore = '';
								$image = '<span><img title="'.$imagetitle.'" alt="'.$imagetitle.'" class="pngfix wp-post-image" src="'.$options['featured_image_slider_image'][ $i ].'" /></span>';
							}

							//Checking Content
							if ( !empty ( $options['featured_image_slider_content'][ $i ] ) ) {
								$content = ' <span class="sep">:</span> <span class="slider-excerpt">' . $options['featured_image_slider_content'][ $i ] . '</span>';
							}
							else {
								$content = '';
							}

							//Content Opening and Closing
							if ( !empty ( $options['featured_image_slider_title'][ $i ] ) || !empty ( $options['featured_image_slider_content'][ $i ] ) ) {
								$contentopening = '<div class="featured-text">';
								$contentclosing = '</div>';
							}
							else {
								$contentopening = '';
								$contentclosing = '';
							}

							$catchbox_imagesliders .= '
							<div class="'.$classes.'">
								<div class="featured-img">
									'.$image.'
								</div>
								'.$contentopening.
									$title.$content.$readmore
								.$contentclosing.'
							</div> <!-- .slides -->';
						}
					}

				$catchbox_imagesliders .= '
				</section> <!-- .slider-wrap -->
				<nav id="nav-slider">
					<div class="nav-previous"><img class="pngfix" src="'.get_template_directory_uri().'/images/previous.png" alt="next slide"></div>
					<div class="nav-next"><img class="pngfix" src="'.get_template_directory_uri().'/images/next.png" alt="next slide"></div>
				</nav>
				<div id="controllers">
				</div><!-- #controllers -->
			</div> <!-- #featured-slider -->';
			set_transient( 'catchbox_imagesliders', $catchbox_imagesliders, 86940 );
		}
		echo $catchbox_imagesliders;
	}
}
endif; //catchbox_imagesliders


if ( ! function_exists( 'catchbox_slider_display' ) ) :
/**
 * Display slider
 */
function catchbox_slider_display() {
	global $wp_query;

	$options  = catchbox_get_options();

	$enableslider = $options['enable_slider'];
	$sliderselect = $options['select_slider_type'];
	$sliderlayout = $options['select_slider_layout'];

	// Front page displays in Reading Settings
	$page_for_posts = get_option('page_for_posts');

	// Get Page ID outside Loop
	$page_id = $wp_query->get_queried_object_id();

	if ( ( 'enable-slider-allpage' == $enableslider ) || ( ( is_front_page() || ( is_home() && $page_id != $page_for_posts ) ) && 'enable-slider-homepage' == $enableslider ) ) :

		// Select Slider
		if ( $sliderselect =='image-slider' && $sliderlayout =='fullwidth' && function_exists( 'catchbox_imagesliders' ) ) {
			add_action( 'catchbox_before_primary', 'catchbox_imagesliders', 10 );
		}
		elseif ( $sliderselect =='post-slider' && $sliderlayout =='fullwidth' && function_exists( 'catchbox_sliders' ) ) {
			add_action( 'catchbox_before_primary', 'catchbox_sliders', 10 );
		}
		elseif ( $sliderselect =='page-slider' && $sliderlayout =='fullwidth' && function_exists( 'catchbox_page_sliders' ) ) {
			add_action( 'catchbox_before_primary', 'catchbox_page_sliders', 10 );
		}
		elseif ( $sliderselect =='category-slider' && $sliderlayout =='fullwidth' && function_exists( 'catchbox_category_sliders' ) ) {
			add_action( 'catchbox_before_primary', 'catchbox_category_sliders', 10 );
		}
		elseif ( $sliderselect =='image-slider' && function_exists( 'catchbox_imagesliders' ) ) {
			add_action( 'catchbox_content', 'catchbox_imagesliders', 10 );
		}
		elseif ( 'post-slider' == $sliderselect && function_exists( 'catchbox_sliders' ) ) {
			add_action( 'catchbox_content', 'catchbox_sliders', 10 );
		}
		elseif ( $sliderselect =='page-slider' && function_exists( 'catchbox_page_sliders' ) ) {
			add_action( 'catchbox_content', 'catchbox_page_sliders', 10 );
		}
		elseif ( 'category-slider' == $sliderselect && function_exists( 'catchbox_category_sliders' ) ) {
			add_action( 'catchbox_content', 'catchbox_category_sliders', 10 );
		}

	endif;

}
endif; //catchbox_slider_display

add_action( 'wp_head', 'catchbox_slider_display', 10 );


/**
 * Alter the query for the main loop in home page
 * @uses pre_get_posts hook
 */
function catchbox_alter_home( $query ){
	if ( $query->is_main_query() && $query->is_home() ) {
		$options = catchbox_get_options();

	    if ( $options[ 'exclude_slider_post'] != "0" && !empty( $options['featured_slider'] ) ) {
			if ( $query->is_main_query() && $query->is_home() ) {
				$query->query_vars['post__not_in'] = $options['featured_slider'];
			}
		}

		if ( is_array( $options['front_page_category'] ) && !in_array( '0', $options['front_page_category'] ) ) {
			$cats = (array) $options['front_page_category'];
			if ( defined( "ICL_LANGUAGE_CODE" ) ) {
				$category = array();
			    foreach( $cats as $cat){
			    	$category[] = apply_filters( 'wpml_object_id', $cat, 'category', true );
			    }
			    $cats = $category;
			}
		}else{
			$cats = '0';
		}

		if ( is_array( $cats ) && !in_array( '0', $cats ) ) {
			$query->query_vars['category__in'] = $cats;
		}
	}
}
add_action( 'pre_get_posts','catchbox_alter_home' );


if ( ! function_exists( 'catchbox_comment_form_fields' ) ) :
/**
 * Altering Comment Form Fields
 * @uses comment_form_default_fields filter
 */
function catchbox_comment_form_fields( $fields ) {
	// get data value from theme options
	$options = catchbox_get_options();
	$disableurl = $options['commenting_disable_url'];

	$req = get_option( 'require_name_email' );
	$aria_req = ( $req ? " aria-required='true'" : '' );
	$commenter = wp_get_current_commenter();

    $fields['author'] = '<p class="comment-form-author"><label for="author">' . esc_attr__( 'Name', 'catch-box-pro' ) . '</label> ' . ( $req ? '<span class="required">*</span>' : '' ) . '<input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" size="30"' . $aria_req . ' /></p>';
    $fields['email'] = '<p class="comment-form-email"><label for="email">' . esc_attr__( 'Email', 'catch-box-pro' ) . '</label> ' . ( $req ? '<span class="required">*</span>' : '' ) . '<input id="email" name="email" type="text" value="' . esc_attr( $commenter['comment_author_email'] ) . '" size="30"' . $aria_req . ' /></p>';

   if ( isset( $fields['url'] ) && '1' == $disableurl ) {
		unset( $fields['url'] );
   }

   return $fields;
}
endif; //catchbox_comment_form_fields

add_filter( 'comment_form_default_fields', 'catchbox_comment_form_fields' );


/**
 * Redirect WordPress Feeds To FeedBurner
 */
function catchbox_rss_redirect() {
	$options  = catchbox_get_options();

    if ( $options['feed_url'] ) {
		$url = 'Location: ' . $options['feed_url'];
		if ( is_feed() && ! preg_match( '/feedburner|feedvalidator/i', $_SERVER['HTTP_USER_AGENT'] ) ) {
			header($url);
			header('HTTP/1.1 302 Temporary Redirect');
		}
	}
}
add_action( 'template_redirect', 'catchbox_rss_redirect' );


/**
 * shows footer content
 */
function catchbox_footer_content() {
	//delete_transient( 'catchbox_footer_content' );

	if ( ( !$catchbox_footer_content = get_transient( 'catchbox_footer_content' ) ) ) {
		echo '<!-- refreshing cache -->';

		// get the data value from theme options
		$options = catchbox_get_options();
		$search  = array( '[the-year]', '[site-link]', '[wp-link]', '[theme-link]' );
		$replace = array( catchbox_the_year(), catchbox_site_link(), catchbox_wp_link(), catchbox_theme_link() );

        $options['footer_code'] = str_replace( $search, $replace, $options['footer_code'] );

        $catchbox_footer_content = $options['footer_code'];

    	set_transient( 'catchbox_footer_content', $catchbox_footer_content, 86940 );
    }
	echo do_shortcode( $catchbox_footer_content );
}
add_action( 'catchbox_site_generator', 'catchbox_footer_content', 15 );


if ( ! function_exists( 'catchbox_social_networks' ) ) :
/**
 * This function for social links display on header
 *
 * @fetch links through Theme Options
 * @use in widget
 * @social links, Facebook, Twitter and RSS
  */
function catchbox_social_networks() {
	//delete_transient( 'catchbox_social_networks' );

	// get the data value from theme options
	$options  = catchbox_get_options();

    $elements = array();

	$elements = array(
		$options['social_facebook'],
		$options['social_twitter'],
		$options['social_googleplus'],
		$options['social_linkedin'],
		$options['social_pinterest'],
		$options['social_youtube'],
		$options['social_vimeo'],
		$options['social_aim'],
		$options['social_myspace'],
		$options['social_flickr'],
		$options['social_tumblr'],
		$options['social_deviantart'],
		$options['social_dribbble'],
		$options['social_myspace'],
		$options['social_wordpress'],
		$options['social_rss'],
		$options['social_slideshare'],
		$options['social_instagram'],
		$options['social_skype'],
		$options['social_soundcloud'],
		$options['social_email'],
		$options['social_xing'],
		$options['social_meetup'],
		$options['social_goodreads'],
		$options['social_github'],
		$options['social_vk'],
		$options['enable_specificfeeds'],
	);

	$flag = 0;
	if ( !empty( $elements ) ) {
		foreach( $elements as $option) {
			if ( !empty( $option ) ) {
				$flag = 1;
			}
			else {
				$flag = 0;
			}
			if ( $flag == 1 ) {
				break;
			}
		}
	}

	if ( ( !$catchbox_social_networks = get_transient( 'catchbox_social_networks' ) ) && ( $flag == 1 ) )  {
		echo '<!-- refreshing cache -->';

		$catchbox_social_networks .='
		<nav class="social-profile" role="navigation" aria-label="' . esc_attr__( 'Social Links Menu', 'catch-box-pro' ) . '"><ul>';

			//facebook
			if ( !empty( $options['social_facebook'] ) ) {
				$catchbox_social_networks .=
					'<li class="facebook"><a href="'.esc_url( $options['social_facebook'] ).'" title="'. esc_attr__( 'Facebook', 'catch-box-pro' ) .'" target="_blank">'. esc_attr__( 'Facebook', 'catch-box-pro' ) .'</a></li>';
			}
			//Twitter
			if ( !empty( $options['social_twitter'] ) ) {
				$catchbox_social_networks .=
					'<li class="twitter"><a href="'.esc_url( $options['social_twitter'] ).'" title="'. esc_attr__( 'Twitter', 'catch-box-pro' ) .'" target="_blank">'. esc_attr__( 'Twitter', 'catch-box-pro' ) .'</a></li>';
			}
			//Google+
			if ( !empty( $options['social_googleplus'] ) ) {
				$catchbox_social_networks .=
					'<li class="google-plus"><a href="'.esc_url( $options['social_googleplus'] ).'" title="'. esc_attr__( 'Google+', 'catch-box-pro' ) .'" target="_blank">'. esc_attr__( 'Google+ ', 'catch-box-pro' ) .'</a></li>';
			}
			//Pinterest
			if ( !empty( $options['social_pinterest'] ) ) {
				$catchbox_social_networks .=
					'<li class="pinterest"><a href="'.esc_url( $options['social_pinterest'] ).'" title="'. esc_attr__( 'Pinterest', 'catch-box-pro' ) .'" target="_blank">'. esc_attr__( 'Pinterest', 'catch-box-pro' ) .'</a></li>';
			}
			//Youtube
			if ( !empty( $options['social_youtube'] ) ) {
				$catchbox_social_networks .=
					'<li class="you-tube"><a href="'.esc_url( $options['social_youtube'] ).'" title="'. esc_attr__( 'YouTube', 'catch-box-pro' ) .'" target="_blank">'. esc_attr__( 'YouTube', 'catch-box-pro' ) .'</a></li>';
			}
			//Vimeo
			if ( !empty( $options['social_vimeo'] ) ) {
				$catchbox_social_networks .=
					'<li class="viemo"><a href="'.esc_url( $options['social_vimeo'] ).'" title="'. esc_attr__( 'Vimeo', 'catch-box-pro' ) .'" target="_blank">'. esc_attr__( 'Vimeo', 'catch-box-pro' ) .'</a></li>';
			}
			//Linkedin
			if ( !empty( $options['social_linkedin'] ) ) {
				$catchbox_social_networks .=
					'<li class="linkedin"><a href="'.esc_url( $options['social_linkedin'] ).'" title="'. esc_attr__( 'Linkedin', 'catch-box-pro' ) .'" target="_blank">'. esc_attr__( 'Linkedin', 'catch-box-pro' ) .'</a></li>';
			}
			//AIM
			if ( !empty( $options['social_aim'] ) ) {
				$catchbox_social_networks .=
					'<li class="aim"><a href="'.esc_url( $options['social_aim'] ).'" title="'. esc_attr__( 'AIM', 'catch-box-pro' ) .'" target="_blank">'. esc_attr__( 'AIM', 'catch-box-pro' ) .'</a></li>';
			}
			//Myspace
			if ( !empty( $options['social_myspace'] ) ) {
				$catchbox_social_networks .=
					'<li class="myspace"><a href="'.esc_url( $options['social_myspace'] ).'" title="'. esc_attr__( 'Myspace', 'catch-box-pro' ) .'" target="_blank">'. esc_attr__( 'Myspace', 'catch-box-pro' ) .'</a></li>';
			}
			//Flickr
			if ( !empty( $options['social_flickr'] ) ) {
				$catchbox_social_networks .=
					'<li class="flickr"><a href="'.esc_url( $options['social_flickr'] ).'" title="'. esc_attr__( 'Flickr', 'catch-box-pro' ) .'" target="_blank">'. esc_attr__( 'Flickr', 'catch-box-pro' ) .'</a></li>';
			}
			//Tumblr
			if ( !empty( $options['social_tumblr'] ) ) {
				$catchbox_social_networks .=
					'<li class="tumblr"><a href="'.esc_url( $options['social_tumblr'] ).'" title="'. esc_attr__( 'Tumblr', 'catch-box-pro' ) .'" target="_blank">'. esc_attr__( 'Tumblr', 'catch-box-pro' ) .'</a></li>';
			}
			//deviantART
			if ( !empty( $options['social_deviantart'] ) ) {
				$catchbox_social_networks .=
					'<li class="deviantart"><a href="'.esc_url( $options['social_deviantart'] ).'" title="'. esc_attr__( 'deviantART', 'catch-box-pro' ) .'" target="_blank">'. esc_attr__( 'deviantART', 'catch-box-pro' ) .'</a></li>';
			}
			//Dribbble
			if ( !empty( $options['social_dribbble'] ) ) {
				$catchbox_social_networks .=
					'<li class="dribbble"><a href="'.esc_url( $options['social_dribbble'] ).'" title="'. esc_attr__( 'Dribbble', 'catch-box-pro' ) .'" target="_blank">'. esc_attr__( 'Dribbble', 'catch-box-pro' ) .'</a></li>';
			}
			//WordPress
			if ( !empty( $options['social_wordpress'] ) ) {
				$catchbox_social_networks .=
					'<li class="wordpress"><a href="'.esc_url( $options['social_wordpress'] ).'" title="'. esc_attr__( 'WordPress', 'catch-box-pro' ) .'" target="_blank">'. esc_attr__( 'WordPress', 'catch-box-pro' ) .'</a></li>';
			}
			//RSS
			if ( !empty( $options['social_rss'] ) ) {
				$catchbox_social_networks .=
					'<li class="rss"><a href="'.esc_url( $options['social_rss'] ).'" title="'. esc_attr__( 'RSS', 'catch-box-pro' ) .'" target="_blank">'. esc_attr__( 'RSS', 'catch-box-pro' ) .'</a></li>';
			}
			//Slideshare
			if ( !empty( $options['social_slideshare'] ) ) {
				$catchbox_social_networks .=
					'<li class="slideshare"><a href="'.esc_url( $options['social_slideshare'] ).'" title="'. esc_attr__( 'Slideshare', 'catch-box-pro' ) .'" target="_blank">'. esc_attr__( 'Slideshare', 'catch-box-pro' ) .'</a></li>';
			}
			//Instagram
			if ( !empty( $options['social_instagram'] ) ) {
				$catchbox_social_networks .=
					'<li class="instagram"><a href="'.esc_url( $options['social_instagram'] ).'" title="'. esc_attr__( 'Instagram', 'catch-box-pro' ) .'" target="_blank">'. esc_attr__( 'Instagram', 'catch-box-pro' ) .'</a></li>';
			}
			//skype
			if ( !empty( $options['social_skype'] ) ) {
				$catchbox_social_networks .=
					'<li class="skype"><a href="'.esc_attr( $options['social_skype'] ).'" title="'. esc_attr__( 'Skype', 'catch-box-pro' ) .'" target="_blank">'. esc_attr__( 'Skype', 'catch-box-pro' ) .'</a></li>';
			}
			//Soundcloud
			if ( !empty( $options['social_soundcloud'] ) ) {
				$catchbox_social_networks .=
					'<li class="soundcloud"><a href="'.esc_url( $options['social_soundcloud'] ).'" title="'. esc_attr__( 'Soundcloud', 'catch-box-pro' ) .'" target="_blank">'. esc_attr__( 'Soundcloud', 'catch-box-pro' ) .'</a></li>';
			}
			//Email
			if ( !empty( $options['social_email'] )  && is_email( $options['social_email'] ) ) {
				$catchbox_social_networks .=
					'<li class="email"><a href="mailto:'.sanitize_email( $options['social_email'] ).'" title="'. esc_attr__( 'Email', 'catch-box-pro' ) .'" target="_blank">'. esc_attr__( 'Email', 'catch-box-pro' ) .'</a></li>';
			}
			//Xing
			if ( !empty( $options['social_xing'] ) ) {
				$catchbox_social_networks .=
					'<li class="xing"><a href="'.esc_url( $options['social_xing'] ).'" title="'. esc_attr__( 'Xing', 'catch-box-pro' ) .'" target="_blank">'. esc_attr__( 'Xing', 'catch-box-pro' ) .'</a></li>';
			}
			//SpecificFeeds
			if ( !empty( $options['enable_specificfeeds'] ) ) {
				$catchbox_social_networks .=
					'<li class="specificfeeds"><a href="'.esc_url( 'http://www.specificfeeds.com/follow' ).'" title="'. esc_attr__( 'SpecificFeeds', 'catch-box-pro' ) .'" target="_blank">'. esc_attr__( 'SpecificFeeds', 'catch-box-pro' ) .'</a></li>';
			}
			//Meetup
			if ( !empty( $options['social_meetup'] ) ) {
				$catchbox_social_networks .=
					'<li class="meetup"><a href="'.esc_url( $options['social_meetup'] ).'" title="'. esc_attr__( 'Meetup', 'catch-box-pro' ) .'" target="_blank">'. esc_attr__( 'Meetup', 'catch-box-pro' ) .'</a></li>';
			}

			//Goodreads
			if ( !empty( $options['social_goodreads'] ) ) {
				$catchbox_social_networks .=
					'<li class="goodreads"><a href="'.esc_url( $options['social_goodreads'] ).'" title="'. esc_attr__( 'Goodreads', 'catch-box-pro' ) .'" target="_blank">'. esc_attr__( 'Goodreads', 'catch-box-pro' ) .'</a></li>';
			}

			//Github
			if ( !empty( $options['social_github'] ) ) {
				$catchbox_social_networks .=
					'<li class="github"><a href="'.esc_url( $options['social_github'] ).'" title="'. esc_attr__( 'Github', 'catch-box-pro' ) .'" target="_blank">'. esc_attr__( 'Github', 'catch-box-pro' ) .'</a></li>';
			}

			//VK
			if ( !empty( $options['social_vk'] ) ) {
				$catchbox_social_networks .=
					'<li class="vk"><a href="'.esc_url( $options['social_vk'] ).'" title="'. esc_attr__( 'VK', 'catch-box-pro' ) .'" target="_blank">'. esc_attr__( 'VK', 'catch-box-pro' ) .'</a></li>';
			}									

			$catchbox_social_networks .='
		</ul></nav>';

		set_transient( 'catchbox_social_networks', $catchbox_social_networks, 86940 );
	}
	echo $catchbox_social_networks;
}
endif; //catchbox_social_networks


/**
 * Footer Social Icons
 *
 */
function catchbox_footer_social() {
	$options  = catchbox_get_options();

	if ( ! $options['disable_footer_social'] ) :
		return catchbox_social_networks();
	endif;
}
add_action( 'catchbox_site_generator', 'catchbox_footer_social', 10 );


/**
 * Site Verification  and Webmaster Tools
 *
 * If user sets the code we're going to display meta verification
 * @get the data value from theme options
 * @uses wp_head action to add the code in the header
 * @uses set_transient and delete_transient API for cache
 */
function catchbox_site_verification() {
	//delete_transient( 'catchbox_site_verification' );

	if ( ( !$catchbox_site_verification = get_transient( 'catchbox_site_verification' ) ) )  {

		// get the data value from theme options
		$options  = catchbox_get_options();

		echo '<!-- refreshing cache -->';

		$catchbox_site_verification = '';
		//google
		if ( !empty( $options['google_verification'] ) ) {
			$catchbox_site_verification .= '<meta name="google-site-verification" content="' .  $options['google_verification'] . '" />' . "\n";
		}
		//bing
		if ( !empty( $options['bing_verification'] ) ) {
			$catchbox_site_verification .= '<meta name="msvalidate.01" content="' .  $options['bing_verification']  . '" />' . "\n";
		}
		//yahoo
		 if ( !empty( $options['yahoo_verification'] ) ) {
			$catchbox_site_verification .= '<meta name="y_key" content="' .  $options['yahoo_verification']  . '" />' . "\n";
		}
		//site stats, analytics header code
		if ( !empty( $options['analytic_header'] ) ) {
			$catchbox_site_verification .=  $options['analytic_header'] ;
		}

		set_transient( 'catchbox_site_verification', $catchbox_site_verification, 86940 );
	}
	echo $catchbox_site_verification;
}
add_action('wp_head', 'catchbox_site_verification');


/**
 * This function loads the Footer Code such as Add this code from the Theme Option
 *
 * @get the data value from theme options
 * @load on the footer ONLY
 * @uses wp_footer action to add the code in the footer
 * @uses set_transient and delete_transient
 */
function catchbox_footercode() {
	//delete_transient( 'catchbox_footercode' );

	if ( ( !$catchbox_footercode = get_transient( 'catchbox_footercode' ) ) ) {

		// get the data value from theme options
		$options  = catchbox_get_options();

		echo '<!-- refreshing cache -->';

		//site stats, analytics header code
		if ( !empty( $options['analytic_footer'] ) ) {
			$catchbox_footercode =  $options['analytic_footer'] ;
		}

		set_transient( 'catchbox_footercode', $catchbox_footercode, 86940 );
	}
	echo $catchbox_footercode;
}
add_action('wp_footer', 'catchbox_footercode');


/**
 * This function loads Scroll Up Navigation
 *
 * @uses catchbox_after action
 */
function catchbox_scrollup() {
	$options = catchbox_get_options();
	if ( ! $options['disable_scrollup'] ) {
		echo '<a href="#branding" id="scrollup"><span class="screen-reader-text">' . esc_html__( 'Scroll Up', 'catch-box-pro' ) . '</span></a>';
	}
}
add_action( 'catchbox_after', 'catchbox_scrollup', 10 );


if ( ! function_exists( 'catchbox_breadcrumb_display' ) ) :
	/**
	 * Display breadcrumb on header
	 */
	function catchbox_breadcrumb_display() {
		if ( function_exists( 'yoast_breadcrumb' ) ) {
			$wpseo_internallinks = get_option( 'wpseo_internallinks' );
			if ( $wpseo_internallinks['breadcrumbs-enable'] == 1 ) {
				echo '<div class="breadcrumbs wpseoyoast">';
					yoast_breadcrumb();
				echo '</div><!-- .wpseoyoast -->';
			}
		}
		elseif ( function_exists( 'bcn_display' ) ) {
			echo '<div class="breadcrumbs breadcrumbnavxt" xmlns:v="http://rdf.data-vocabulary.org/#">';
					bcn_display();
			echo '</div><!-- .breadcrumbnavxt -->';
		}
	}
endif; // catchbox_breadcrumb_display
add_action( 'catchbox_content', 'catchbox_breadcrumb_display', 20 );
