<?php
/**
 * Catch Box Customizer/Theme Options
 *
 * @package Catch Themes
 * @subpackage Catch Box
 * @since Catch Box 3.6.7
 */

/**
 * Implements Catch Box theme options into Theme Customizer.
 *
 * @param $wp_customize Theme Customizer object
 * @return void
 *
 * @since Catch Box 3.6.7
 */
function catchbox_customize_register( $wp_customize ) {
	$options  = catchbox_get_options();

	$defaults = catchbox_defaults();

	//Custom Controls
	require trailingslashit( get_template_directory() ) . 'inc/customizer/customizer-custom-controls.php';

	$theme_slug = 'catchbox_theme_';

	$settings_page_tabs = array(
		'theme_options' => array(
			'id' 			=> 'theme_options',
			'title' 		=> esc_html__( 'Theme Options', 'catch-box-pro' ),
			'description' 	=> esc_html__( 'Basic theme Options', 'catch-box-pro' ),
			'sections' 		=> array(
				'disable_responsive'	=> array(
					'id' 			=> 'disable_responsive',
					'title' 		=> esc_html__( 'Responsive Design', 'catch-box-pro' ),
					'description' 	=> '',
				),
				'mobile_menu' => array(
					'id' 			=> 'mobile_menu',
					'title' 		=> esc_html__( 'Mobile Menu Options', 'catch-box-pro' ),
					'description' 	=> '',
				),
				'header_options' => array(
					'id' 			=> 'header_options',
					'title' 		=> esc_html__( 'Header Options', 'catch-box-pro' ),
					'description' 	=> '',
				),
				'search_display_text' => array(
					'id' 			=> 'search_display_text',
					'title' 		=> esc_html__( 'Search Text Settings', 'catch-box-pro' ),
					'description' 	=> '',
				),
				'font_family' => array(
					'id' 			=> 'font_family',
					'title' 		=> esc_html__( 'Font Family Option', 'catch-box-pro' ),
					'description' 	=> '',
				),
				'font_size' => array(
					'id' 			=> 'font_size',
					'title' 		=> esc_html__( 'Font Size Options', 'catch-box-pro' ),
					'description' 	=> '',
				),
				'theme_layout' => array(
					'id' 			=> 'theme_layout',
					'title' 		=> esc_html__( 'Default Layout', 'catch-box-pro' ),
					'description' 	=> '',
				),
				'content_layout' => array(
					'id' 			=> 'content_layout',
					'title' 		=> esc_html__( 'Content Layout', 'catch-box-pro' ),
					'description' 	=> '',
				),
				'category_setting' => array(
					'id' 			=> 'category_setting',
					'title' 		=> esc_html__( 'Front Page Category Setting', 'catch-box-pro' ),
					'description' 	=> '',
				),
				'excerpt_length' => array(
					'id' 			=> 'excerpt_length',
					'title' 		=> esc_html__( 'Excerpt Length in Words', 'catch-box-pro' ),
					'description' 	=> '',
				),
				'feed_url' => array(
					'id' 			=> 'feed_url',
					'title' 		=> esc_html__( 'Feed Redirect URL', 'catch-box-pro' ),
					'description' 	=> '',
				),
				'comment_options' => array(
					'id' 			=> 'comment_options',
					'title' 		=> esc_html__( 'Comment Options', 'catch-box-pro' ),
					'description' 	=> '',
				),
				'footer_editor' => array(
					'id' 			=> 'footer_editor',
					'title'			=> esc_html__( 'Footer Editor Options', 'catch-box-pro' ),
					'description' 	=> ''
				),
				'custom_css' => array(
					'id' 			=> 'custom_css',
					'title' 		=> esc_html__( 'Custom CSS Styles', 'catch-box-pro' ),
					'description' 	=> '',
				),
				'scrollup' => array(
					'id' 			=> 'scrollup',
					'title' 		=> esc_html__( 'Scroll Up Options', 'catch-box-pro' ),
					'description' 	=> '',
				),
				'update_notifier' => array(
					'id' 			=> 'update_notifier',
					'title' 		=> esc_html__( 'Update Notifier Options', 'catch-box-pro' ),
					'description' 	=> '',
				),
			),
		),

		'featured_slider' => array(
			'id' 			=> 'featured_slider',
			'title' 		=> esc_html__( 'Featured Slider', 'catch-box-pro' ),
			'description' 	=> esc_html__( 'Featured Slider', 'catch-box-pro' ),
			'sections' 		=> array(
				'slider_options' => array(
					'id' 			=> 'slider_options',
					'title' 		=> esc_html__( 'Slider Options', 'catch-box-pro' ),
					'description' 	=> '',
				),
				'slider_effect_options' => array(
					'id' 			=> 'slider_effect_options',
					'title' 		=> esc_html__( 'Slider Effect Options', 'catch-box-pro' ),
					'description' 	=> '',
				),
			)
		),

		'colors' => array(
			'id' 			=> 'colors',
			'title' 		=> esc_html__( 'Colors', 'catch-box-pro' ),
			'description' 	=> '',
			'priority'		=> '10',
			'sections' 		=> array(
				'basic_colors' => array(
					'id' 			=> 'basic_colors',
					'title' 		=> esc_html__( 'Basic Colors', 'catch-box-pro' ),
					'description' 	=> '',
				),
				'custom_colors' => array(
					'id' 			=> 'custom_colors',
					'title' 		=> esc_html__( 'Custom Color Options', 'catch-box-pro' ),
					'description' 	=> '',
				),
			),
		),

		'social_links' => array(
			'id' 			=> 'social_links',
			'title' 		=> esc_html__( 'Social Links', 'catch-box-pro' ),
			'description' 	=> esc_html__( 'Add your social links here', 'catch-box-pro' ),
			'sections' 		=> array(
				'predefined_social_icons' => array(
					'id' 			=> 'predefined_social_icons',
					'title' 		=> esc_html__( 'Predefined Social Icons', 'catch-box-pro' ),
					'description' 	=> '',
				),
			),
		),
		'webmaster_tools' => array(
			'id' 			=> 'webmaster_tools',
			'title' 		=> esc_html__( 'Webmaster Tools', 'catch-box-pro' ),
			'description' 	=>  '',
			'sections' 		=> array(
				'site_verification' => array(
					'id' 			=> 'site_verification',
					'title' 		=> esc_html__( 'Site Verification', 'catch-box-pro' ),
					'description' 	=> '',
				),
				'header_footer_codes' => array(
					'id' 			=> 'header_footer_codes',
					'title' 		=> esc_html__( 'Header And Footer Codes', 'catch-box-pro' ),
					'description' 	=> '',
				),
			),
		),
	);

	//Add Panels and sections
	foreach ( $settings_page_tabs as $panel ) {
		$panel_priority = 200;

		if ( 'colors' === $panel['id'] ) {
			$panel_priority = 30;
		}
		$wp_customize->add_panel(
			$theme_slug . $panel['id'],
			array(
				'priority' 		=> $panel_priority,
				'capability' 	=> 'edit_theme_options',
				'title' 		=> $panel['title'],
				'description' 	=> $panel['description'],
			)
		);

		// Loop through tabs for sections
		foreach ( $panel['sections'] as $section ) {
			$params = array(
								'title'			=> $section['title'],
								'description'	=> $section['description'],
								'panel'			=> $theme_slug . $panel['id']
							);

			if ( isset( $section['active_callback'] ) ) {
				$params['active_callback'] = $section['active_callback'];
			}

			$wp_customize->add_section(
				// $id
				$theme_slug . $section['id'],
				// parameters
				$params

			);
		}
	}

	foreach( catchbox_content_layout() as $option ) {
		$catchbox_content_layout[ $option['value'] ] =  $option['label'];
	}

	//Move default header color and background color under custom section basic_colors
	$wp_customize->get_control( 'header_textcolor' )->section = $theme_slug . 'basic_colors' ;
	$wp_customize->get_control( 'header_textcolor' )->priority = 20 ;

	$wp_customize->get_control( 'background_color' )->section = $theme_slug . 'basic_colors' ;
	$wp_customize->get_control( 'background_color' )->priority = 25 ;


	$settings_parameters = array(
		'disable_responsive' => array(
			'id' 				=> 'disable_responsive',
			'title' 			=> esc_html__( 'Check to disable responsive design', 'catch-box-pro' ),
			'description'		=> '',
			'field_type' 		=> 'checkbox',
			'sanitize' 			=> 'catchbox_sanitize_checkbox',
			'panel' 			=> 'theme_options',
			'section' 			=> 'disable_responsive',
			'default' 			=> $defaults['disable_responsive'],
		),

		//Color Scheme
		'color_scheme' => array(
			'id' 			=> 'color_scheme',
			'title' 		=> esc_html__( 'Color Scheme', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'radio',
			'sanitize' 		=> 'catchbox_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'basic_colors',
			'default' 		=> $defaults['color_scheme'],
			'choices'		=> catchbox_color_schemes(),
		),

		//Custom Color Options
		'header_background' => array(
			'id' 			=> 'header_background',
			'title' 		=> esc_html__( 'Header Background Color', 'catch-box-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_colors',
			'default' 		=> $defaults['header_background']
		),
		'slider_background' => array(
			'id' 			=> 'slider_background',
			'title' 		=> esc_html__( 'Slider Background Color', 'catch-box-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_colors',
			'default' 		=> $defaults['slider_background']
		),
		'content_background' => array(
			'id' 			=> 'content_background',
			'title' 		=> esc_html__( 'Content Background Color', 'catch-box-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_colors',
			'default' 		=> $defaults['content_background']
		),
		'article_background' => array(
			'id' 			=> 'article_background',
			'title' 		=> esc_html__( 'Article Background Color', 'catch-box-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_colors',
			'default' 		=> $defaults['article_background']
		),
		'footer_background' => array(
			'id' 			=> 'footer_background',
			'title' 		=> esc_html__( 'Footer Background Color', 'catch-box-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_colors',
			'default' 		=> $defaults['footer_background']
		),
		'footer_sidebar_background' => array(
			'id' 			=> 'footer_sidebar_background',
			'title' 		=> esc_html__( 'Footer Sidebar Background Color', 'catch-box-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_colors',
			'default' 		=> $defaults['footer_sidebar_background']
		),
		'widget_background' => array(
			'id' 			=> 'widget_background',
			'title' 		=> esc_html__( 'Widget Background Color', 'catch-box-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_colors',
			'default' 		=> $defaults['widget_background']
		),
		'title_hover_color' => array(
			'id' 			=> 'title_hover_color',
			'title' 		=> esc_html__( 'Site Title Hover Color', 'catch-box-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_colors',
			'default' 		=> $defaults['title_hover_color']
		),
		'heading_color' => array(
			'id' 			=> 'heading_color',
			'title' 		=> esc_html__( 'Title Color', 'catch-box-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_colors',
			'default' 		=> $defaults['heading_color']
		),
		'heading_hover_color' => array(
			'id' 			=> 'heading_hover_color',
			'title' 		=> esc_html__( 'Title Hover Color', 'catch-box-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_colors',
			'default' 		=> $defaults['heading_hover_color']
		),
		'slider_text' => array(
			'id' 			=> 'slider_text',
			'title' 		=> esc_html__( 'Slider Text Color', 'catch-box-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_colors',
			'default' 		=> $defaults['slider_text']
		),
		'meta_color' => array(
			'id' 			=> 'meta_color',
			'title' 		=> esc_html__( 'Meta Description Color', 'catch-box-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_colors',
			'default' 		=> $defaults['meta_color']
		),
		'text_color' => array(
			'id' 			=> 'text_color',
			'title' 		=> esc_html__( 'Text Color', 'catch-box-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_colors',
			'default' 		=> $defaults['text_color']
		),
		'link_color' => array(
			'id' 			=> 'link_color',
			'title' 		=> esc_html__( 'Link Color', 'catch-box-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_colors',
			'default' 		=> $defaults['link_color']
		),
		'widget_heading_color' => array(
			'id' 			=> 'widget_heading_color',
			'title' 		=> esc_html__( 'Sidebar Widget Title Color', 'catch-box-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_colors',
			'default' 		=> $defaults['widget_heading_color']
		),
		'widget_text_color' => array(
			'id' 			=> 'widget_text_color',
			'title' 		=> esc_html__( 'Sidebar Widget Text Color', 'catch-box-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_colors',
			'default' 		=> $defaults['widget_text_color']
		),
		'menu_background' => array(
			'id' 			=> 'menu_background',
			'title' 		=> esc_html__( 'Menu Background Color', 'catch-box-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_colors',
			'default' 		=> $defaults['menu_background']
		),
		'menu_color' => array(
			'id' 			=> 'menu_color',
			'title' 		=> esc_html__( 'Menu Text Color', 'catch-box-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_colors',
			'default' 		=> $defaults['menu_color']
		),
		'hover_background_color' => array(
			'id' 			=> 'hover_background_color',
			'title' 		=> esc_html__( 'Menu Hover Background Color', 'catch-box-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_colors',
			'default' 		=> $defaults['hover_background_color']
		),
		'hover_text_color' => array(
			'id' 			=> 'hover_text_color',
			'title' 		=> esc_html__( 'Menu Hover Text Color', 'catch-box-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_colors',
			'default' 		=> $defaults['hover_text_color']
		),
		'active_background_color' => array(
			'id' 			=> 'active_background_color',
			'title' 		=> esc_html__( 'Menu Active Background Color', 'catch-box-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_colors',
			'default' 		=> $defaults['active_background_color']
		),
		'active_text_color' => array(
			'id' 			=> 'active_text_color',
			'title' 		=> esc_html__( 'Menu Active Text Color', 'catch-box-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_colors',
			'default' 		=> $defaults['active_text_color']
		),
		'sub_menu_bg_color' => array(
			'id' 			=> 'sub_menu_bg_color',
			'title' 		=> esc_html__( 'Sub-Menu Background Color', 'catch-box-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_colors',
			'default' 		=> $defaults['sub_menu_bg_color']
		),
		'sub_menu_text_color' => array(
			'id' 			=> 'sub_menu_text_color',
			'title' 		=> esc_html__( 'Sub-Menu Text Color', 'catch-box-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_colors',
			'default' 		=> $defaults['sub_menu_text_color']
		),
		'scrollup_bg_color' => array(
			'id' 			=> 'scrollup_bg_color',
			'title' 		=> esc_html__( 'Scroll Up Background Color', 'catch-box-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_colors',
			'default' 		=> $defaults['scrollup_bg_color']
		),
		'scrollup_text_color' => array(
			'id' 			=> 'scrollup_text_color',
			'title' 		=> esc_html__( 'Scroll Up Text Color', 'catch-box-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_colors',
			'default' 		=> $defaults['scrollup_text_color']
		),
		'reset_color' => array(
			'id' 			=> 'reset_color',
			'title' 		=> esc_html__( 'Check to reset color', 'catch-box-pro' ),
			'description'	=> esc_html__( 'Please refresh the customizer after saving if reset option is used', 'catch-box-pro' ),
			'transport'		=> 'postMessage',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'catchbox_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_colors',
			'default' 		=> $defaults['reset_color']
		),

		//Sidebar Layout
		'sidebar_layout' => array(
			'id' 			=> 'sidebar_layout',
			'title' 		=> esc_html__( 'Default Layout', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'catchbox_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'theme_layout',
			'default' 		=> $defaults['sidebar_layout'],
			'choices'		=> catchbox_layouts(),
		),
		'woocommerce_layout' => array(
			'id' 			=> 'woocommerce_layout',
			'title' 		=> esc_html__( 'WooCommerce Layout', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'catchbox_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'theme_layout',
			'default' 		=> $defaults['woocommerce_layout'],
			'choices'		=> catchbox_layouts(),
		),
		'reset_sidebar_layout' => array(
			'id' 			=> 'reset_sidebar_layout',
			'title' 		=> esc_html__( 'Check to Reset Default Layout', 'catch-box-pro' ),
			'description'	=> esc_html__( 'Please refresh the customizer after saving if reset option is used', 'catch-box-pro' ),
			'transport'		=> 'postMessage',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'catchbox_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'theme_layout',
			'default' 		=> $defaults['reset_sidebar_layout'],
		),

		//Content Layout
		'content_layout' => array(
			'id' 			=> 'content_layout',
			'title' 		=> esc_html__( 'Content Layout', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'radio',
			'sanitize' 		=> 'catchbox_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'content_layout',
			'default' 		=> $defaults['content_layout'],
			'choices'		=> $catchbox_content_layout,
		),
		'show_updated' => array(
			'id'              => 'show_updated',
			'title'           => esc_html__( 'Check to display Posts Updated Date', 'catch-box-pro' ),
			'description'	  => '',
			'field_type'      => 'checkbox',
			'sanitize'        => 'catchbox_sanitize_checkbox',
			'panel'           => 'theme_options',
			'section'         => 'content_layout',
			'default'         => $defaults['show_updated'],
		),
		'front_page_category' => array(
			'id' 			=> 'front_page_category',
			'title' 		=> esc_html__( 'Front Page Category', 'catch-box-pro' ),
			'description'	=> esc_html__( 'Only posts that belong to the categories selected here will be displayed on the front page. <br /> You may select multiple categories by holding down the CTRL key.', 'catch-box-pro' ),
			'field_type' 	=> 'category-multiple',
			'sanitize' 		=> 'catchbox_sanitize_category_list',
			'panel' 		=> 'theme_options',
			'section' 		=> 'category_setting',
			'default' 		=> $defaults['front_page_category'],
			'choices'		=> $catchbox_content_layout,
		),
		//Excerpt length
		'excerpt_length' => array(
			'id' 			=> 'excerpt_length',
			'title' 		=> esc_html__( 'Excerpt Length in Words', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'number',
			'sanitize' 		=> 'catchbox_sanitize_number_range',
			'panel' 		=> 'theme_options',
			'section' 		=> 'excerpt_length',
			'default' 		=> $defaults['excerpt_length'],
			'input_attrs' 	=> array(
					            'style' => 'width: 100px;',
					            'min'   => 0,
					            'max'   => 999999,
					            'step'  => 1,
					        	)
		),
		'more_tag_accessible' => array(
			'id' 			=> 'more_tag_accessible',
			'title' 		=> esc_html__( 'Check to make More Text Tag accessible', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'catchbox_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'excerpt_length',
			'default' 		=> $defaults['more_tag_accessible'],
		),
		'more_tag_text' => array(
			'active_callback' => 'catchbox_is_more_tag_inaccessible',
			'id'              => 'more_tag_text',
			'title'           => esc_html__( 'More Text Tag', 'catch-box-pro' ),
			'description'     => '',
			'field_type'      => 'text',
			'sanitize'        => 'sanitize_text_field',
			'panel'           => 'theme_options',
			'section'         => 'excerpt_length',
			'default'         => $defaults['more_tag_text'],
		),
		'more_tag_text_accessible' => array(
			'active_callback' => 'catchbox_is_more_tag_accessible',
			'id'              => 'more_tag_text_accessible',
			'title'           => esc_html__( 'More Text Tag', 'catch-box-pro' ),
			'description'     => '',
			'field_type'      => 'text',
			'sanitize'        => 'sanitize_text_field',
			'panel'           => 'theme_options',
			'section'         => 'excerpt_length',
			'default'         => $defaults['more_tag_text_accessible'],
		),
		'more_tag_icon_accessible' => array(
			'active_callback' => 'catchbox_is_more_tag_accessible',
			'id'              => 'more_tag_icon_accessible',
			'title'           => esc_html__( 'More Text Icon', 'catch-box-pro' ),
			'description'     => '',
			'field_type'      => 'text',
			'sanitize'        => 'sanitize_text_field',
			'panel'           => 'theme_options',
			'section'         => 'excerpt_length',
			'default'         => $defaults['more_tag_icon_accessible'],
		),

		//Comment Options
		'commenting_setting' => array(
			'id' 			=> 'commenting_setting',
			'title' 		=> esc_html__( 'Disable Comment', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'catchbox_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'comment_options',
			'default' 		=> $defaults['commenting_setting'],
			'choices'		=> catchbox_comment_option(),
		),
		'commenting_disable_url' => array(
			'id' 			=> 'commenting_disable_url',
			'title' 		=> esc_html__( 'Check to disable website field', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'catchbox_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'comment_options',
			'default' 		=> $defaults['commenting_disable_url'],
		),

		//Footer Editor Options
		'footer_code' => array(
			'id' 			=> 'footer_code',
			'title' 		=> esc_html__( 'Footer Editor', 'catch-box-pro' ),
			'description'	=> esc_html__( 'You can add custom HTML and/or shortcodes, which will be automatically inserted into your theme.Some shorcodes: [the-year], [site-link], [wp-link] for current year, your site link, wordpress site link respectively.', 'catch-box-pro' ),
			'field_type' 	=> 'textarea',
			'sanitize' 		=> 'catchbox_sanitize_footer_code',
			'panel' 		=> 'theme_options',
			'section' 		=> 'footer_editor',
			'default' 		=> $defaults['footer_code'],
		),
		'reset_footer' => array(
			'id' 			=> 'reset_footer',
			'title' 		=> esc_html__( 'Check to reset footer', 'catch-box-pro' ),
			'description'	=> esc_html__( 'Please refresh the customizer after saving if reset option is used', 'catch-box-pro' ),
			'transport'		=> 'postMessage',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'catchbox_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'footer_editor',
			'default' 		=> $defaults['reset_footer'],
		),

		'feed_url' => array(
			'id' 				=> 'feed_url',
			'title' 			=> esc_html__( 'Feed Redirect url', 'catch-box-pro' ),
			'description' 		=> '',
			'field_type' 		=> 'url',
			'sanitize' 			=> 'esc_url_raw',
			'panel' 			=> 'theme_options',
			'section' 			=> 'feed_url',
			'default' 			=> $defaults['feed_url'],
		),

		//Header Options
		'site_title_above' => array(
			'id' 			=> 'site_title_above',
			'title' 		=> esc_html__( 'Check to move above the Header/Logo Image', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'catchbox_sanitize_checkbox',
			'section' 		=> 'title_tagline',
			'default' 		=> $defaults['site_title_above']
		),
		'disable_header_search' => array(
			'id' 			=> 'disable_header_search',
			'title' 		=> esc_html__( 'Check to disable header right sidebar', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'catchbox_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'header_options',
			'default' 		=> $defaults['disable_header_search']
		),
		'header_top_size' => array(
			'id' 			=> 'header_top_size',
			'title' 		=> esc_html__( 'Header Top Margin', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'header_options',
			'default' 		=> $defaults['header_top_size']
		),
		'header_right_size' => array(
			'id' 			=> 'header_right_size',
			'title' 		=> esc_html__( 'Header Right Margin', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'header_options',
			'default' 		=> $defaults['header_right_size']
		),
		'header_bottom_size' => array(
			'id' 			=> 'header_bottom_size',
			'title' 		=> esc_html__( 'Header Bottom Margin', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'header_options',
			'default' 		=> $defaults['header_bottom_size']
		),
		'header_left_size' => array(
			'id' 			=> 'header_left_size',
			'title' 		=> esc_html__( 'Header Left Margin', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'header_options',
			'default' 		=> $defaults['header_left_size']
		),
		'reset_header_space' => array(
			'id' 			=> 'reset_header_space',
			'title' 		=> esc_html__( 'Check to reset header margin', 'catch-box-pro' ),
			'description'	=> esc_html__( 'Please refresh the customizer after saving if reset option is used', 'catch-box-pro' ),
			'transport'		=> 'postMessage',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'catchbox_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'header_options',
			'default' 		=> $defaults['reset_header_space']
		),

		//Font Family
		'body_font' => array(
			'id' 			=> 'body_font',
			'title' 		=> esc_html__( 'Default Font Family', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'catchbox_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'font_family',
			'default' 		=> $defaults['body_font'],
			'choices'		=> catchbox_available_fonts(),
		),
		'title_font' => array(
			'id' 			=> 'title_font',
			'title' 		=> esc_html__( 'Site Title & Description Font Family', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'catchbox_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'font_family',
			'default' 		=> $defaults['title_font'],
			'choices'		=> catchbox_available_fonts(),
		),
		'headings_font' => array(
			'id' 			=> 'headings_font',
			'title' 		=> esc_html__( 'Headings Font Family', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'catchbox_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'font_family',
			'default' 		=> $defaults['headings_font'],
			'choices'		=> catchbox_available_fonts(),
		),
		'content_font' => array(
			'id' 			=> 'content_font',
			'title' 		=> esc_html__( 'Content Font Family', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'catchbox_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'font_family',
			'default' 		=> $defaults['content_font'],
			'choices'		=> catchbox_available_fonts(),
		),
		'reset_typography' => array(
			'id' 			=> 'reset_typography',
			'title' 		=> esc_html__( 'Check to reset fonts', 'catch-box-pro' ),
			'description'	=> esc_html__( 'Please refresh the customizer after saving if reset option is used', 'catch-box-pro' ),
			'transport'		=> 'postMessage',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'catchbox_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'font_family',
			'default' 		=> $defaults['reset_typography'],
			'choices'		=> catchbox_available_fonts(),
		),

		//Font Size
		'body_font_size' => array(
			'id' 			=> 'body_font_size',
			'title' 		=> esc_html__( 'Default Font Size', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'font_size',
			'default' 		=> $defaults['body_font_size'],
		),
		'body_line_height' => array(
			'id' 			=> 'body_line_height',
			'title' 		=> esc_html__( 'Default Line Height', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'font_size',
			'default' 		=> $defaults['body_line_height'],
		),
		'site_title_font_size' => array(
			'id' 			=> 'site_title_font_size',
			'title' 		=> esc_html__( 'Site Title Font Size', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'font_size',
			'default' 		=> $defaults['site_title_font_size'],
		),
		'site_title_line_height' => array(
			'id' 			=> 'site_title_line_height',
			'title' 		=> esc_html__( 'Site Title Line Height', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'font_size',
			'default' 		=> $defaults['site_title_line_height'],
		),
		'site_description_font_size' => array(
			'id' 			=> 'site_description_font_size',
			'title' 		=> esc_html__( 'Site Description Font Size', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'font_size',
			'default' 		=> $defaults['site_description_font_size'],
		),
		'site_description_line_height' => array(
			'id' 			=> 'site_description_line_height',
			'title' 		=> esc_html__( 'Site Description Line Height', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'font_size',
			'default' 		=> $defaults['site_description_line_height'],
		),
		'title_font_size' => array(
			'id' 			=> 'title_font_size',
			'title' 		=> esc_html__( 'Page/Post Title Font Size', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'font_size',
			'default' 		=> $defaults['title_font_size'],
		),
		'h1_font_size' => array(
			'id' 			=> 'h1_font_size',
			'title' 		=> esc_html__( 'H1 Font Size', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'font_size',
			'default' 		=> $defaults['h1_font_size'],
		),
		'h2_font_size' => array(
			'id' 			=> 'h2_font_size',
			'title' 		=> esc_html__( 'H2 Font Size', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'font_size',
			'default' 		=> $defaults['h2_font_size'],
		),
		'h3_font_size' => array(
			'id' 			=> 'h3_font_size',
			'title' 		=> esc_html__( 'H3 Font Size', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'font_size',
			'default' 		=> $defaults['h3_font_size'],
		),
		'h4_font_size' => array(
			'id' 			=> 'h4_font_size',
			'title' 		=> esc_html__( 'H4 Font Size', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'font_size',
			'default' 		=> $defaults['h4_font_size'],
		),
		'headings_line_height' => array(
			'id' 			=> 'headings_line_height',
			'title' 		=> esc_html__( 'Headings Line Height', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'font_size',
			'default' 		=> $defaults['headings_line_height'],
		),
		'content_font_size' => array(
			'id' 			=> 'content_font_size',
			'title' 		=> esc_html__( 'Content Font Size', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'font_size',
			'default' 		=> $defaults['content_font_size'],
		),
		'content_line_height' => array(
			'id' 			=> 'content_line_height',
			'title' 		=> esc_html__( 'Content Line Height', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'font_size',
			'default' 		=> $defaults['content_line_height'],
		),
		'reset_typography_font_size' => array(
			'id' 			=> 'reset_typography_font_size',
			'title' 		=> esc_html__( 'Check to reset font size', 'catch-box-pro' ),
			'description'	=> esc_html__( 'Please refresh the customizer after saving if reset option is used', 'catch-box-pro' ),
			'transport'		=> 'postMessage',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'catchbox_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'font_size',
			'default' 		=> $defaults['reset_typography_font_size'],
		),

		'search_display_text' => array(
			'id' 			=> 'search_display_text',
			'title' 		=> esc_html__( 'Default Display Text in Search', 'catch-box-pro' ),
			'description'	=> '',
			'description'	=> '',
			'field_type' 	=> 'text',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'search_display_text',
			'default' 		=> $defaults['search_display_text']
		),

		//Mobile Menu Options
		'enable_sec_menu' => array(
			'id' 			=> 'enable_sec_menu',
			'title' 		=> esc_html__( 'Check to enable secondary mobile menu', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'catchbox_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'mobile_menu',
			'default' 		=> $defaults['enable_sec_menu']
		),
		'enable_footer_menu' => array(
			'id' 			=> 'enable_footer_menu',
			'title' 				=> esc_html__( 'Check to enable footer mobile menu', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'catchbox_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'mobile_menu',
			'default' 		=> $defaults['enable_footer_menu']
		),
		'primary_mobile_menu_label' => array(
			'id' 			=> 'primary_mobile_menu_label',
			'title' 		=> esc_html__( 'Primary Mobile Menu Label', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'text',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'mobile_menu',
			'default' 		=> $defaults['primary_mobile_menu_label']
		),
		'secondary_mobile_menu_label' => array(
			'id' 			=> 'secondary_mobile_menu_label',
			'title' 		=> esc_html__( 'Secondary Mobile Menu Label', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'text',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'mobile_menu',
			'default' 		=> $defaults['secondary_mobile_menu_label']
		),
		'footer_mobile_menu_label' => array(
			'id' 			=> 'footer_mobile_menu_label',
			'title' 		=> esc_html__( 'Footer Mobile Menu Label', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'text',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'mobile_menu',
			'default' 		=> $defaults['footer_mobile_menu_label']
		),
		'hide_mobile_menu_labels' => array(
			'id' 			=> 'hide_mobile_menu_labels',
			'title' 		=> esc_html__( 'Check to hide mobile menu labels', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'catchbox_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'mobile_menu',
			'default' 		=> $defaults['hide_mobile_menu_labels']
		),

		//Custom CSS
		'custom_css' => array(
			'id' 			=> 'custom_css',
			'title' 		=> esc_html__( 'Custom CSS Styles', 'catch-box-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'textarea',
			'sanitize' 		=> 'catchbox_sanitize_custom_css',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_css',
			'default' 		=> ''
		),

		//Scroll Up Options
		'disable_scrollup' => array(
			'id' 			=> 'disable_scrollup',
			'title' 		=> esc_html__( 'Check to disable scroll up', 'catch-box-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'catchbox_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'scrollup',
			'default' 		=> $defaults['disable_scrollup'],
		),

		//Update Notifier Options
		'disable_notifier' => array(
			'id' 			=> 'disable_notifier',
			'title' 		=> esc_html__( 'Check to disable update notifier', 'catch-box-pro' ),
			'description' 	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'catchbox_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'update_notifier',
			'default' 		=> $defaults['disable_notifier'],
		),

		//Slider Options
		'enable_slider' => array(
			'id' 				=> 'enable_slider',
			'title' 			=> esc_html__( 'Enable Slider', 'catch-box-pro' ),
			'description'		=> '',
			'field_type' 		=> 'select',
			'sanitize' 			=> 'catchbox_sanitize_select',
			'panel' 			=> 'featured_slider',
			'section' 			=> 'slider_options',
			'default' 			=> $defaults['enable_slider'],
			'choices'			=> catchbox_enable_slider_options()
		),
		'select_slider_layout' => array(
			'id' 				=> 'select_slider_layout',
			'title' 			=> esc_html__( 'Slider Layout', 'catch-box-pro' ),
			'description'		=> '',
			'field_type' 		=> 'select',
			'sanitize' 			=> 'catchbox_sanitize_select',
			'panel' 			=> 'featured_slider',
			'section' 			=> 'slider_options',
			'default' 			=> $defaults['select_slider_layout'],
			'choices'			=> catchbox_slider_layouts(),
			'active_callback'	=> 'catchbox_is_slider_active'
		),
		'slider_qty' => array(
			'id' 				=> 'slider_qty',
			'title' 			=> esc_html__( 'Number of Slides', 'catch-box-pro' ),
			'description'		=> esc_html__( 'Customizer page needs to be refreshed after saving if number of slides is changed', 'catch-box-pro' ),
			'field_type' 		=> 'number',
			'sanitize' 			=> 'catchbox_sanitize_number_range',
			'panel' 			=> 'featured_slider',
			'section' 			=> 'slider_options',
			'default' 			=> $defaults['slider_qty'],
			'input_attrs' 		=> array(
						            'style' => 'width: 45px;',
						            'min'   => 0,
						            'max'   => 20,
						            'step'  => 1,
						        	),
			'active_callback'	=> 'catchbox_is_slider_active'
		),
		'select_slider_type' => array(
			'id' 				=> 'select_slider_type',
			'title' 			=> esc_html__( 'Slider Type', 'catch-box-pro' ),
			'description'		=> '',
			'field_type' 		=> 'select',
			'sanitize' 			=> 'catchbox_sanitize_select',
			'panel' 			=> 'featured_slider',
			'section' 			=> 'slider_options',
			'default' 			=> $defaults['select_slider_type'],
			'choices'			=> catchbox_slider_types(),
			'active_callback'	=> 'catchbox_is_slider_active'
		),
		'exclude_slider_post' => array(
			'id' 				=> 'exclude_slider_post',
			'title' 			=> esc_html__( 'Check to Exclude Slider posts from Homepage posts', 'catch-box-pro' ),
			'description'		=> '',
			'field_type' 		=> 'checkbox',
			'sanitize' 			=> 'catchbox_sanitize_checkbox',
			'panel' 			=> 'featured_slider',
			'section' 			=> 'slider_options',
			'default' 			=> $defaults['exclude_slider_post'],
			'active_callback'	=> 'catchbox_is_post_slider_active'
		),
		'slider_category' => array(
			'id' 				=> 'slider_category',
			'title' 			=> esc_html__( 'Select Slider Categories', 'catch-box-pro' ),
			'description'		=> esc_html__( 'Use this only is you want to display posts from Specific Categories in Featured Slider', 'catch-box-pro' ),
			'field_type' 		=> 'category-multiple',
			'sanitize' 			=> 'catchbox_sanitize_category_list',
			'panel' 			=> 'featured_slider',
			'section' 			=> 'slider_options',
			'default' 			=> $defaults['slider_category'],
			'priority'			=> '90',
			'active_callback' 	=> 'catchbox_is_category_slider_active',
		),

		'transition_effect' => array(
			'id' 				=> 'transition_effect',
			'title' 			=> esc_html__( 'Transition Effect', 'catch-box-pro' ),
			'description'		=> '',
			'field_type' 		=> 'select',
			'sanitize' 			=> 'catchbox_sanitize_select',
			'panel' 			=> 'featured_slider',
			'section' 			=> 'slider_effect_options',
			'default' 			=> $defaults['transition_effect'],
			'choices'			=> array(
										'fade'			=> esc_html__( 'fade', 'catch-box-pro' ),
										'wipe'			=> esc_html__( 'wipe', 'catch-box-pro' ),
										'scrollUp'		=> esc_html__( 'scrollUp', 'catch-box-pro' ),
										'scrollDown'	=> esc_html__( 'scrollDown', 'catch-box-pro' ),
										'scrollLeft'	=> esc_html__( 'scrollLeft', 'catch-box-pro' ),
										'scrollRight'	=> esc_html__( 'scrollRight', 'catch-box-pro' ),
										'blindX'		=> esc_html__( 'blindX', 'catch-box-pro' ),
										'blindY'		=> esc_html__( 'blindY', 'catch-box-pro' ),
										'blindZ'		=> esc_html__( 'blindZ', 'catch-box-pro' ),
										'cover'			=> esc_html__( 'cover', 'catch-box-pro' ),
										'shuffle'		=> esc_html__( 'shuffle', 'catch-box-pro' ),
									),
			'active_callback'	=> 'catchbox_is_slider_active'
		),
		'transition_delay' => array(
			'id' 				=> 'transition_delay',
			'title' 			=> esc_html__( 'Transition Delay (in seconds)', 'catch-box-pro' ),
			'description'		=> '',
			'field_type' 		=> 'number',
			'sanitize' 			=> 'catchbox_sanitize_number_range',
			'panel' 			=> 'featured_slider',
			'section' 			=> 'slider_effect_options',
			'default' 			=> $defaults['transition_delay'],
			'input_attrs' 		=> array(
						            'style' => 'width: 45px;',
						            'min'   => 0,
						            'max'   => 999999999,
						            'step'  => 1,
						        	),
			'active_callback'	=> 'catchbox_is_slider_active'
		),
		'transition_duration' => array(
			'id' 				=> 'transition_duration',
			'title' 			=> esc_html__( 'Transition Length', 'catch-box-pro' ),
			'description'		=> '',
			'field_type' 		=> 'number',
			'sanitize' 			=> 'catchbox_sanitize_number_range',
			'panel' 			=> 'featured_slider',
			'section' 			=> 'slider_effect_options',
			'default' 			=> $defaults['transition_duration'],
			'input_attrs' 		=> array(
						            'style' => 'width: 45px;',
						            'min'   => 0,
						            'max'   => 999999999,
						            'step'  => 1,
						        	),
			'active_callback'	=> 'catchbox_is_slider_active'
		),

		//Social Links
		'disable_footer_social' => array(
			'id' 			=> 'disable_footer_social',
			'title' 		=> esc_html__( 'Check to disable social links on footer', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'catchbox_sanitize_checkbox',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> $defaults['disable_footer_social'],
		),
		'social_facebook' => array(
			'id' 			=> 'social_facebook',
			'title' 		=> esc_html__( 'Facebook', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> ''
		),
		'social_twitter' => array(
			'id' 			=> 'social_twitter',
			'title' 		=> esc_html__( 'Twitter', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> ''
		),
		'social_googleplus' => array(
			'id' 			=> 'social_googleplus',
			'title' 		=> esc_html__( 'Google+', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> ''
		),
		'social_pinterest' => array(
			'id' 			=> 'social_pinterest',
			'title' 		=> esc_html__( 'Pinterest', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> ''
		),
		'social_youtube' => array(
			'id' 			=> 'social_youtube',
			'title' 		=> esc_html__( 'Youtube', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> ''
		),
		'social_vimeo' => array(
			'id' 			=> 'social_vimeo',
			'title' 		=> esc_html__( 'Vimeo', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> ''
		),
		'social_linkedin' => array(
			'id' 			=> 'social_linkedin',
			'title' 		=> esc_html__( 'LinkedIn', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> ''
		),
		'social_aim' => array(
			'id' 			=> 'social_aim',
			'title' 		=> esc_html__( 'Aim', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> ''
		),
		'social_myspace' => array(
			'id' 			=> 'social_myspace',
			'title' 		=> esc_html__( 'MySpace', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> ''
		),
		'social_flickr' => array(
			'id' 			=> 'social_flickr',
			'title' 		=> esc_html__( 'Flickr', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'sanitize_email',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> ''
		),
		'social_tumblr' => array(
			'id' 			=> 'social_tumblr',
			'title' 		=> esc_html__( 'Tumblr', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> ''
		),
		'social_deviantart' => array(
			'id' 			=> 'social_deviantart',
			'title' 		=> esc_html__( 'deviantART', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> ''
		),
		'social_dribbble' => array(
			'id' 			=> 'social_dribbble',
			'title' 		=> esc_html__( 'Dribbble', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> ''
		),
		'social_wordpress' => array(
			'id' 			=> 'social_wordpress',
			'title' 		=> esc_html__( 'WordPress', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> ''
		),
		'social_rss' => array(
			'id' 			=> 'social_rss',
			'title' 		=> esc_html__( 'RSS', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> ''
		),
		'social_slideshare' => array(
			'id' 			=> 'social_slideshare',
			'title' 		=> esc_html__( 'Slideshare', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> ''
		),
		'social_instagram' => array(
			'id' 			=> 'social_instagram',
			'title' 		=> esc_html__( 'Instagram', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> ''
		),
		'social_skype' => array(
			'id' 			=> 'social_skype',
			'title' 		=> esc_html__( 'Skype', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> ''
		),
		'social_soundcloud' => array(
			'id' 			=> 'social_soundcloud',
			'title' 		=> esc_html__( 'Soundcloud', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> ''
		),
		'social_email' => array(
			'id' 			=> 'social_email',
			'title' 		=> esc_html__( 'Email', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'sanitize_email',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> ''
		),
		'social_xing' => array(
			'id' 			=> 'social_xing',
			'title' 		=> esc_html__( 'Xing', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> ''
		),
		'enable_specificfeeds' => array(
			'id' 			=> 'enable_specificfeeds',
			'title' 		=> esc_html__( 'Check to Enable SpecificFeeds', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'catchbox_sanitize_checkbox',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> ''
		),
		'social_meetup' => array(
			'id' 			=> 'social_meetup',
			'title' 		=> esc_html__( 'Meetup', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> ''
		),
		'social_goodreads' => array(
			'id' 			=> 'social_goodreads',
			'title' 		=> esc_html__( 'Goodreads', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> ''
		),
		'social_github' => array(
			'id' 			=> 'social_github',
			'title' 		=> esc_html__( 'Github', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> ''
		),
		'social_vk' => array(
			'id' 			=> 'social_vk',
			'title' 		=> esc_html__( 'VK', 'catch-box-pro' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'panel' 		=> 'social_links',
			'section' 		=> 'predefined_social_icons',
			'default' 		=> ''
		),						

		//Webmaster Tools
		'google_verification' => array(
			'id' 				=> 'google_verification',
			'title' 			=> esc_html__( 'Google Site Verification ID', 'catch-box-pro' ),
			'description' 		=> esc_html__( 'Enter your Google ID number only ', 'catch-box-pro' ),
			'field_type' 		=> 'text',
			'sanitize' 			=> 'wp_filter_post_kses',
			'panel' 			=> 'webmaster_tools',
			'section' 			=> 'site_verification',
			'default' 			=> $defaults['google_verification'],
		),
		'yahoo_verification' => array(
			'id' 				=> 'yahoo_verification',
			'title' 			=> esc_html__( 'Yahoo Site Verification ID', 'catch-box-pro' ),
			'description' 		=> esc_html__( 'Enter your Yahoo ID number only ', 'catch-box-pro' ),
			'field_type' 		=> 'text',
			'sanitize' 			=> 'wp_filter_post_kses',
			'panel' 			=> 'webmaster_tools',
			'section' 			=> 'site_verification',
			'default' 			=> $defaults['yahoo_verification'],
		),
		'bing_verification' => array(
			'id' 				=> 'bing_verification',
			'title' 			=> esc_html__( 'Bing Site Verification', 'catch-box-pro' ),
			'description' 		=> esc_html__( 'Enter your Bing ID number only ', 'catch-box-pro' ),
			'field_type' 		=> 'text',
			'sanitize' 			=> 'wp_filter_post_kses',
			'panel' 			=> 'webmaster_tools',
			'section' 			=> 'site_verification',
			'default' 			=> $defaults['bing_verification'],
		),
		'analytic_header' => array(
			'id' 				=> 'analytic_header',
			'title' 			=> esc_html__( 'Code to display on Header', 'catch-box-pro' ),
			'description' 		=> esc_html__( 'Here you can put scripts from Google, Facebook etc. which will load on Header', 'catch-box-pro' ),
			'field_type' 		=> 'textarea',
			'sanitize' 			=> 'wp_kses_stripslashes',
			'panel' 			=> 'webmaster_tools',
			'section' 			=> 'header_footer_codes',
			'default' 			=> $defaults['analytic_header'],
		),
		'analytic_footer' => array(
			'id' 				=> 'analytic_footer',
			'title' 			=> esc_html__( 'Code to display on Footer', 'catch-box-pro' ),
			'description' 		=> esc_html__( 'Here you can put scripts from Google, Facebook etc. which will load on Footer', 'catch-box-pro' ),
			'field_type' 		=> 'textarea',
			'sanitize' 			=> 'wp_kses_stripslashes',
			'panel' 			=> 'webmaster_tools',
			'section' 			=> 'header_footer_codes',
			'default' 			=> $defaults['analytic_footer'],
		),
	);

	if( function_exists( 'has_custom_logo' ) ) {
		$settings_header_image = array(
			//Favicon
			'header_image_position' => array(
				'id'          => 'header_image_position',
				'title'       => esc_html__( 'Header Image Location', 'catch-box-pro' ),
				'description' => '',
				'field_type'  => 'select',
				'sanitize'    => 'catchbox_sanitize_select',
				'section'     => 'header_image',
				'default'     => $defaults['header_image_position'],
				'choices'     => array(
					'above'   => esc_html__( 'Above Header Content', 'catch-box-pro' ),
					'between' => esc_html__( 'Between Site Title-Logo', 'catch-box-pro' ),
					'below'   => esc_html__( 'Below Header Content', 'catch-box-pro' )
				)
			)
		);

		$settings_parameters = array_merge( $settings_parameters, $settings_header_image);
	}

	//@remove Remove if block and custom_css from $settings_paramater when WordPress 5.0 is released
	if( function_exists( 'wp_update_custom_css_post' ) ) {
		unset( $settings_parameters['custom_css'] );
	}

	foreach ( $settings_parameters as $option ) {
		$priority = isset( $option['priority'] ) ? $option['priority'] : '';
		$transport = isset( $option['transport'] ) ? $option['transport'] : 'refresh';

		if( 'color' == $option['field_type'] ) {
			$wp_customize->add_setting(
				// $id
				$theme_slug . 'options[' . $option['id'] . ']',
				// parameters array
				array(
					'sanitize_callback'	=> $option['sanitize'],
					'default'			=> $option['default'],
					'transport'			=> $transport
				)
			);

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize,$theme_slug . 'options[' . $option['id'] . ']',
					array(
						'label'		=> $option['title'],
						'section'   => $theme_slug . $option['section'],
						'settings'  => $theme_slug . 'options[' . $option['id'] . ']',
						'priority'	=> $priority
					)
				)
			);
		}
		else if( 'image' == $option['field_type'] ) {
			$wp_customize->add_setting(
				// $id
				$theme_slug . 'options[' . $option['id'] . ']',
				// parameters array
				array(
					'sanitize_callback'	=> $option['sanitize'],
					'default'			=> $option['default'],
					'transport'			=> $transport
				)
			);

			$wp_customize->add_control(
				new WP_Customize_Image_Control(
					$wp_customize,$theme_slug . 'options[' . $option['id'] . ']',
					array(
						'label'				=> $option['title'],
						'section'   		=> $theme_slug . $option['section'],
						'settings'  		=> $theme_slug . 'options[' . $option['id'] . ']',
						'active_callback'	=> $option['active_callback'],
					)
				)
			);
		}
		else if ('checkbox' == $option['field_type'] ) {
			$wp_customize->add_setting(
				// $id
				$theme_slug . 'options[' . $option['id'] . ']',
				// parameters array
				array(
					'sanitize_callback'	=> $option['sanitize'],
					'default'			=> $option['default'],
					'transport'			=> $transport
				)
			);

			$params = array(
						'label'		=> $option['title'],
						'settings'  => $theme_slug . 'options[' . $option['id'] . ']',
						'name'  	=> $theme_slug . 'options[' . $option['id'] . ']',
						'section'	=> $theme_slug . $option['section']
					);

			if ( isset( $option['active_callback']  ) ){
				$params['active_callback'] = $option['active_callback'];
			}

			if ( 'title_tagline' == $option['section'] ) {
				$params['section'] = $option['section'];
			}
			else {
				$params['section']	= $theme_slug . $option['section'];
			}

			$wp_customize->add_control(
				new CatchBox_Customize_Checkbox(
					$wp_customize,$theme_slug . 'options[' . $option['id'] . ']',
					$params
				)
			);
		}
		else if ('category-multiple' == $option['field_type'] ) {
			$wp_customize->add_setting(
				// $id
				$theme_slug . 'options[' . $option['id'] . ']',
				// parameters array
				array(
					'sanitize_callback'	=> $option['sanitize'],
					'default'			=> $option['default'],
					'transport'			=> $transport
				)
			);

			$params = array(
						'label'			=> $option['title'],
						'section'		=> $theme_slug . $option['section'],
						'settings'		=> $theme_slug . 'options[' . $option['id'] . ']',
						'description'	=> $option['description'],
						'name'	 		=> $theme_slug . 'options[' . $option['id'] . ']',
						'priority'		=> $priority,
					);

			if ( isset( $option['active_callback']  ) ){
				$params['active_callback'] = $option['active_callback'];
			}

			$wp_customize->add_control(
				new Catchbox_Customize_Dropdown_Categories_Control (
					$wp_customize,
					$theme_slug . 'options[' . $option['id'] . ']',
					$params
				)
			);
		}
		//For Font Size
		else if( 'multiple-input' == $option['field_type'] ){
			/* Body Font Size */
			$option1_id = $option['id'];
			$option2_id = $option['id'].'_unit';

			$wp_customize->add_setting( $theme_slug .'options['. $option1_id .']', array(
		            'default'        	=> $defaults[$option1_id],
		            'capability'     	=> 'edit_theme_options',
		            'sanitize_callback'	=> $option['sanitize'],
		        ) );

			$wp_customize->add_setting( $theme_slug .'options['. $option2_id .']', array(
		            'default'        	=> $defaults[$option2_id],
		            'capability'     	=> 'edit_theme_options',
		            'sanitize_callback'	=> $option['sanitize'],
		        ) );

			$control = new Catchbox_Customize_Multiple_Input_Control(
	            $wp_customize, $theme_slug .'options['. $option1_id .']', array(
	            'label'    		=> $option['title'],
	            'section'  		=> $theme_slug . $option['section'],
	            'settings'   	=> array (
	                $theme_slug .'options['. $option1_id .']',
	                $theme_slug .'options['. $option2_id .']',
	            )
	        ) );

		    $wp_customize->add_control( $control );
		}
		else {

			//Normal Loop
			$wp_customize->add_setting(
				// $id
				$theme_slug . 'options[' . $option['id'] . ']',
				// parameters array
				array(
					'default'			=> $option['default'],
					'sanitize_callback'	=> $option['sanitize'],
					'transport'			=> $transport
				)
			);

			// Add setting control
			$params = array(
					'label'			=> $option['title'],
					'settings'		=> $theme_slug . 'options[' . $option['id'] . ']',
					'type'			=> $option['field_type'],
					'description'   => $option['description']
				);

			if ( 'header_image' == $option['section'] ) {
				$params['section'] = $option['section'];
			}
			else {
				$params['section']	= $theme_slug . $option['section'];
			}

			if ( isset( $option['active_callback']  ) ){
				$params['active_callback'] = $option['active_callback'];
			}

			if ( isset( $option['choices']  ) ){
				$params['choices'] = $option['choices'];
			}

			if ( isset( $option['input_attrs']  ) ){
				$params['input_attrs'] = $option['input_attrs'];
			}

			$wp_customize->add_control(
				// $id
				$theme_slug . 'options[' . $option['id'] . ']',
				$params
			);
		}
	}

	if( !isset( $options['slider_qty'] ) || !is_numeric( $options['slider_qty'] ) ) {
		$options['slider_qty'] = 4;
	}

    //Add featured post elements with respect to no of featured sliders
	for ( $i = 1; $i <= $options['slider_qty']; $i++ ) {
		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[featured_slider][' . $i . ']',
			// parameters array
			array(
				'sanitize_callback'	=> 'catchbox_sanitize_post_id'
			)
		);

		$wp_customize->add_control(
			$theme_slug . 'options[featured_slider][' . $i . ']',
			array(
				'label'		=> sprintf( esc_html__( '#%s Featured Post ID', 'catch-box-pro' ), $i ),
				'section'   => $theme_slug .'slider_options',
				'settings'  => $theme_slug . 'options[featured_slider][' . $i . ']',
				'type'		=> 'text',
					'input_attrs' => array(
	        		'style' => 'width: 100px;'
	    		),
				'active_callback' 	=> 'catchbox_is_post_slider_active'
			)
		);
	}


	//Add featured page elements with respect to no of featured slider
	for ( $i = 1; $i <= $options['slider_qty']; $i++ ) {
		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[featured_slider_page][' . $i . ']',
			// parameters array
			array(
				'sanitize_callback'	=> 'catchbox_sanitize_post_id'
			)
		);

		$wp_customize->add_control(
			$theme_slug . 'options[featured_slider_page][' . $i . ']',
			array(
				'label'		=> sprintf( esc_html__( 'Featured Page Slider #%s', 'catch-box-pro' ), $i ),
				'section'   => $theme_slug .'slider_options',
				'settings'  => $theme_slug . 'options[featured_slider_page][' . $i . ']',
				'type'	   	=> 'dropdown-pages',
				'active_callback' 	=> 'catchbox_is_page_slider_active'
			)
		);
	}

	//Add featured image elements with respect to no of featured slider
	for ( $i = 1; $i <= $options['slider_qty']; $i++ ) {
		$wp_customize->add_setting( $theme_slug . 'options[featured_slider_note]['. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'sanitize_text_field',
		) );

		$wp_customize->add_control( new Catchbox_Note_Control(
			$wp_customize,
			$theme_slug . 'options[featured_slider_note]['. $i .']', array(
	        'label'		=> esc_html__( 'Featured Slide #', 'catch-box-pro' ) . $i,
	        'section'  	=> $theme_slug .'slider_options',
	        'settings'	=> $theme_slug . 'options[featured_slider_note][' . $i . ']',
	        'type'     	=> 'description',
	        'active_callback'	=> 'catchbox_is_image_slider_active',
   		) ) );

		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[featured_image_slider_image][' . $i . ']',
			// parameters array
			array(
				'sanitize_callback'	=> 'catchbox_sanitize_image'
			)
		);

		$wp_customize->add_control( new WP_Customize_Image_Control(
				$wp_customize,
				$theme_slug . 'options[featured_image_slider_image][' . $i . ']',
				array(
					'label'				=> esc_html__( 'Image', 'catch-box-pro' ),
					'section'   		=> $theme_slug .'slider_options',
					'settings'  		=> $theme_slug . 'options[featured_image_slider_image][' . $i . ']',
					'active_callback' 	=> 'catchbox_is_image_slider_active'
				)
			)
		);

		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[featured_image_slider_link][' . $i . ']',
			// parameters array
			array(
				'sanitize_callback'	=> 'esc_url_raw'
			)
		);

		$wp_customize->add_control(
			$theme_slug . 'options[featured_image_slider_link][' . $i . ']',
			array(
				'label'				=> esc_html__( 'Link', 'catch-box-pro' ),
				'section'   		=> $theme_slug .'slider_options',
				'settings'  		=> $theme_slug . 'options[featured_image_slider_link][' . $i . ']',
				'type'	   			=> 'url',
				'active_callback' 	=> 'catchbox_is_image_slider_active'
			)
		);

		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[featured_image_slider_base][' . $i . ']',
			// parameters array
			array(
				'sanitize_callback'	=> 'catchbox_sanitize_checkbox'
			)
		);

		$wp_customize->add_control(
			$theme_slug . 'options[featured_image_slider_base][' . $i . ']',
			array(
				'label'				=> esc_html__( 'Check to Open Link in New Window/Tab ', 'catch-box-pro' ),
				'section'   		=> $theme_slug .'slider_options',
				'settings'  		=> $theme_slug . 'options[featured_image_slider_base][' . $i . ']',
				'type'	   			=> 'checkbox',
				'active_callback' 	=> 'catchbox_is_image_slider_active'
			)
		);

		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[featured_image_slider_title][' . $i . ']',
			// parameters array
			array(
				'sanitize_callback'	=> 'sanitize_text_field'
			)
		);

		$wp_customize->add_control(
			$theme_slug . 'options[featured_image_slider_title][' . $i . ']',
			array(
				'label'				=> esc_html__( 'Title', 'catch-box-pro' ),
				'section'   		=> $theme_slug .'slider_options',
				'settings'  		=> $theme_slug . 'options[featured_image_slider_title][' . $i . ']',
				'type'	   			=> 'text',
				'active_callback' 	=> 'catchbox_is_image_slider_active'
			)
		);

		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[featured_image_slider_content][' . $i . ']',
			// parameters array
			array(
				'sanitize_callback'	=> 'sanitize_text_field'
			)
		);

		$wp_customize->add_control(
			$theme_slug . 'options[featured_image_slider_content][' . $i . ']',
			array(
				'label'				=> esc_html__( 'Content', 'catch-box-pro' ),
				'section'   		=> $theme_slug .'slider_options',
				'settings'  		=> $theme_slug . 'options[featured_image_slider_content][' . $i . ']',
				'type'	   			=> 'textarea',
				'active_callback' 	=> 'catchbox_is_image_slider_active'
			)
		);
	}


	// Reset all settings to default
	$wp_customize->add_section( 'catchbox_reset_all_settings', array(
		'description'	=> esc_html__( 'Caution: Reset all settings to default. Refresh the page after save to view full effects.', 'catch-box-pro' ),
		'priority' 		=> 700,
		'title'    		=> esc_html__( 'Reset all settings', 'catch-box-pro' ),
	) );

	$wp_customize->add_setting( 'catchbox_theme_options[reset_all_settings]', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback' => 'catchbox_sanitize_checkbox',
		'transport'			=> 'postMessage',
	) );

	$wp_customize->add_control( 'catchbox_theme_options[reset_all_settings]', array(
		'label'    => esc_html__( 'Check to reset all settings to default', 'catch-box-pro' ),
		'section'  => 'catchbox_reset_all_settings',
		'settings' => 'catchbox_theme_options[reset_all_settings]',
		'type'     => 'checkbox'
	) );
	// Reset all settings to default end

	//Important Links
	$wp_customize->add_section( 'important_links', array(
		'priority' 		=> 999,
		'title'   	 	=> esc_html__( 'Important Links', 'catch-box-pro' ),
	) );

	/**
	 * Has dummy Sanitizaition function as it contains no value to be sanitized
	 */
	$wp_customize->add_setting( 'important_links', array(
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new CatchBox_Important_Links( $wp_customize, 'important_links', array(
        'label'   	=> esc_html__( 'Important Links', 'catch-box-pro' ),
        'section'  	=> 'important_links',
        'settings' 	=> 'important_links',
        'type'     	=> 'important_links',
    ) ) );
    //Important Links End
}
add_action( 'customize_register', 'catchbox_customize_register' );


/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously for catchbox.
 * And flushes out all transient data on preview
 *
 * @since Catch Box 3.4
 */
function catchbox_customize_preview() {
	//Remove transients on preview
	catchbox_flush_transients();
}
add_action( 'customize_preview_init', 'catchbox_customize_preview' );
add_action( 'customize_save', 'catchbox_customize_preview' );


/**
 * Custom scripts and styles on Customizer for Catch Box
 *
 * @since Catch Box 3.3
 */
function catchbox_customize_scripts() {
    wp_enqueue_script( 'catchbox_customizer_custom', get_template_directory_uri() . '/js/customizer-custom-scripts.js', array( 'jquery' ), '20140108', true );

    $catchbox_data = array(
		'reset_message' => esc_html__( 'Refresh the customizer page after saving to view reset effects', 'catch-box-pro' ),
		'reset_options' => array(
			'catchbox_theme_options[reset_header_space]',
			'catchbox_theme_options[reset_color]',
			'catchbox_theme_options[reset_typography]',
			'catchbox_theme_options[reset_typography_font_size]',
			'catchbox_theme_options[reset_sidebar_layout]',
			'catchbox_theme_options[reset_footer]',
			'catchbox_theme_options[reset_all_settings]',
		)
	);

	// Send reset message as object to custom customizer js
	wp_localize_script( 'catchbox_customizer_custom', 'catchbox_data', $catchbox_data );
}
add_action( 'customize_controls_enqueue_scripts', 'catchbox_customize_scripts' );


/*
 * Clearing the cache if any changes in Admin Theme Option
 */
function catchbox_flush_transients(){
	delete_transient( 'catchbox_responsive' ); // Disable responsive layout
	delete_transient( 'catchbox_inline_css' ); // Custom Inline CSS and color options
	delete_transient( 'catchbox_sliders' ); // featured post slider
	delete_transient( 'catchbox_page_sliders' ); // featured page slider
	delete_transient( 'catchbox_category_sliders' ); // featured category slider
	delete_transient( 'catchbox_imagesliders' ); // featured image slider
	delete_transient( 'catchbox_social_networks' );  // Social links on header
	delete_transient( 'catchbox_site_verification' ); // scripts which loads on header
	delete_transient( 'catchbox_footercode' ); // scripts which loads on footer
	delete_transient( 'catchbox_footer_content' ); // Footer content
}

/*
 * Clearing the cache if any changes in post or page
 */
function catchbox_post_invalidate_caches(){
	delete_transient( 'catchbox_sliders' ); // featured post slider
	delete_transient( 'catchbox_page_sliders' ); // featured page slider
	delete_transient( 'catchbox_category_sliders' ); // featured category slider
}
//Add action hook here save post
add_action( 'save_post', 'catchbox_post_invalidate_caches' );


/**
 * Function to reset date with respect to condition
 *
 * @since Catch Box Pro 4.9
 */
function catchbox_reset_data() {
	$options  = catchbox_get_options();
    
    if ( $options['reset_all_settings'] ) {
    	remove_theme_mods();

    	// Flush out all transients	on reset
        catchbox_flush_transients();

        return;
    }

	if ( '1' == $options['reset_header_space'] ) {
    	unset( 
    		$options['header_top_size'],
    		$options['header_top_size_unit'],
    		$options['header_right_size'],
    		$options['header_right_size_unit'],
    		$options['header_bottom_size'],
    		$options['header_bottom_size_unit'],
    		$options['header_left_size'],
    		$options['header_left_size_unit'],
    		$options['reset_header_space'] 
    	);
    }

    if ( '1' == $options['reset_color'] ) {
    	unset( 
    		$options['color_scheme'],
    		$options['header_background'],
    		$options['slider_background'],
    		$options['content_background'],
    		$options['article_background'],
    		$options['footer_background'],
    		$options['footer_sidebar_background'],
    		$options['widget_background'],
    		$options['title_hover_color'],
    		$options['heading_color'],
    		$options['heading_hover_color'],
    		$options['slider_text'],
    		$options['meta_color'],
    		$options['text_color'],
    		$options['link_color'],
    		$options['widget_heading_color'],
    		$options['widget_text_color'],
    		$options['menu_background'],
    		$options['menu_color'],
    		$options['hover_background_color'],
    		$options['hover_text_color'],
    		$options['active_background_color'],
    		$options['active_text_color'],
    		$options['sub_menu_bg_color'],
    		$options['sub_menu_text_color'],
    		$options['scrollup_bg_color'],
    		$options['scrollup_text_color'],
    		$options['reset_color'] 
    	);
    }

    if ( '1' == $options['reset_typography'] ) {
    	unset( 
    		$options['body_font'],
    		$options['title_font'],
    		$options['headings_font'],
    		$options['content_font'],
    		$options['reset_typography'] 
    	);
	}

	if ( '1' == $options['reset_typography_font_size'] ) {
    	unset( 
    		$options['body_font_size'],
    		$options['body_font_size_unit'],
    		$options['body_line_height'],
    		$options['body_line_height_unit'],
    		$options['site_title_font_size'],
    		$options['site_title_font_size_unit'],
    		$options['site_title_line_height'],
    		$options['site_title_line_height_unit'],
    		$options['site_description_font_size'],
    		$options['site_description_font_size_unit'],
    		$options['site_description_line_height'],
    		$options['site_description_line_height_unit'],
    		$options['h1_font_size'],
    		$options['h1_font_size_unit'],
    		$options['h2_font_size'],
    		$options['h2_font_size_unit'],
    		$options['h3_font_size'],
    		$options['h3_font_size_unit'],
    		$options['h4_font_size'],
    		$options['h4_font_size_unit'],
    		$options['headings_line_height'],
    		$options['headings_line_height_unit'],
    		$options['content_font_size'],
    		$options['content_font_size_unit'],
    		$options['content_line_height'],
    		$options['content_line_height_unit'],
    		$options['reset_typography_font_size'] 
    	);
	}

	if ( '1' == $options['reset_sidebar_layout'] ) {
		unset( 
			$options['sidebar_layout'],
			$options['reset_sidebar_layout'] 
		);
	}

	if ( '1' == $options['reset_footer'] ) {
		unset( 
			$options['footer_code'],
			$options['reset_footer'] 
		);
	}

	set_theme_mod( 'catchbox_theme_options', $options );

	catchbox_flush_transients();
}
add_action( 'customize_save_after', 'catchbox_reset_data' );


//Active callbacks for customizer
require trailingslashit( get_template_directory() ) . 'inc/customizer/customizer-active-callbacks.php';

//Sanitize functions for customizer
require trailingslashit( get_template_directory() ) . 'inc/customizer/customizer-sanitize-functions.php';